;=============================================================================
; Original MOD file: "beast.MOD"
; Original MOD name: "Beast-Playtune2     "
; ASM file created by Mod2PSG V1.6 by Martin Konrad (mkon@gmx.de)
;=============================================================================



;=============================================================================
; Constants
;=============================================================================
RAM_START    = $C000
CONTROL_PORT = $DC
GAME_GEAR_STEREO_SOUND_PORT = $06

;=============================================================================
; PSGMOD variables
;=============================================================================
PSGMOD_PATTERN_ADDRESS  = RAM_START     ;(word)
PSGMOD_SONG_START       = RAM_START + 2 ;(word)
PSGMOD_SONG_POSITION    = RAM_START + 4 ;(byte)
PSGMOD_PATTERN_POSITION = RAM_START + 5 ;(byte)
PSGMOD_CURRENT_SPEED    = RAM_START + 6 ;(byte)
PSGMOD_SPEED_COUNTER    = RAM_START + 7 ;(byte)
PSGMOD_SOUND_DISABLED   = RAM_START + 8 ;(byte)

;=============================================================================
; Misc variables
;=============================================================================
VBLANK_COUNTER          = RAM_START + 9  ;(byte)
PREVIOUS_CONTROL_STATUS = RAM_START + 10 ;(byte)



;=============================================================================
; Start code
;=============================================================================
.org $0000
  di
  im 1
  ld sp, $dff0
  jr START

;=============================================================================
; IRQ handler
;=============================================================================
.org $0038
  exx
  ex af, af'
  in a, ($BF)

  ld hl, VBLANK_COUNTER
  inc (HL)

  exx
  ex af, af'
  ei
  reti

;=============================================================================
; NMI handler
;=============================================================================
.org $0066
  retn



START:
  call SETUP_FRAMES
  call SET_VDP_REGS_TABLE

; Set Game Gear stereo sound mask
  ld a, 195
  out (GAME_GEAR_STEREO_SOUND_PORT), a

;=============================================================================
; Song start
;=============================================================================
    ld hl, PSGMOD_SONG
  call PSGMOD_INITIATE_NEW_SONG
  ei
SONG_LOOP:
    ld d, 1                       ; wait one VBlank
  call VWAIT

  call PSGMOD_PLAY_NEXT_NOTE      ; play next note

  in a, (CONTROL_PORT)            ; get control status
  ld b, a                         ; save it to b
  ld a, (PREVIOUS_CONTROL_STATUS) ; button already pressed before?
  bit 4, a
  jr Z, BUTTON_NOT_PRESSED_AGAIN  ; jump away if yes
  ld a, b                         ; button now pressed?
  bit 4, a
  jr NZ, BUTTON_NOT_PRESSED_AGAIN ; jump away if not
  call PSGMOD_TOGGLE_SOUND        ; toggle sound on or off
BUTTON_NOT_PRESSED_AGAIN:
  ld a, b                         ; get control status from b
  ld (PREVIOUS_CONTROL_STATUS), a ; save control status to previous
                                  ; control status

  jr SONG_LOOP
;=============================================================================
; Program end
;=============================================================================

.include PSGMOD.INC



VWAIT:
  ld a, 0
  ld (VBLANK_COUNTER), a
VWAIT_LOOP:
  ld a, (VBLANK_COUNTER)
  cp d
  ret Z
  jr VWAIT_LOOP

SETUP_FRAMES:
  ld a, 0
  ld ($FFFC), a
  ld ($FFFD), a
  ld a, 1
  ld ($FFFE), a
  ld a, 2
  ld ($FFFF), a
  ret

SET_VDP_REGS_TABLE:
  ld hl, VDP_REGS_TABLE
  ld b, $0f
  ld c, $80
VDP_REGS_LOOP:
  ld a, (HL)
  inc hl
  out ($bf), a
  ld a, c
  inc c
  out ($bf), a
  dec b
  jr NZ, VDP_REGS_LOOP
  ret

VDP_REGS_TABLE:
   .db $06, $60, $FF, $FF, $FF, $FF, $00, $00, $00, $00, $FF, $00, $00, $00, $00, $00

PSGMOD_SONG:
.db 0,1,0,1,2,3,4,5
.db 6,7,6,8,9,10,11,12
.db 13,14,13,15,16,17,18,19
.db 20,21,20,22,23,24,25,26
.db 128,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0

; Pattern 0:
.dw 2963,2963,4466,835,15,2963,15,783,
.dw 15,2963,15,783,15,2963,15,783,
.dw 2803,2963,2813,783,15,2963,15,783,
.dw 15,2963,2813,783,15,2963,15,783,
.dw 2963,2963,4466,835,15,2963,15,783,
.dw 15,2963,15,783,15,2963,15,783,
.dw 2803,2963,2813,783,15,2963,15,783,
.dw 2963,2963,2813,783,15,2963,15,783,
.dw 15,2963,4466,835,15,2963,15,783,
.dw 2803,2963,15,783,15,2963,15,783,
.dw 15,2963,2813,783,15,2963,15,783,
.dw 2963,2963,2813,783,15,2963,15,783,
.dw 2963,2963,4466,835,15,2963,15,783,
.dw 15,2963,15,783,15,2963,15,783,
.dw 2803,2963,2813,783,15,2963,15,783,
.dw 15,2963,2813,783,15,2963,15,783,
.dw 2963,2963,4466,835,15,2963,15,783,
.dw 15,2963,15,783,15,2963,15,783,
.dw 2803,2963,2813,783,15,2963,15,783,
.dw 15,2963,2813,783,15,2963,15,783,
.dw 2963,2963,4466,835,15,2963,15,783,
.dw 15,2963,15,783,15,2963,15,783,
.dw 2803,2963,2813,783,15,2963,15,783,
.dw 2963,2963,2813,783,15,2963,15,783,
.dw 15,2963,4466,835,15,2963,15,783,
.dw 2803,2963,15,783,15,2963,15,783,
.dw 15,2963,2813,783,15,2963,15,783,
.dw 2963,2963,2813,835,15,2963,15,783,
.dw 2963,2963,4466,835,15,2963,15,783,
.dw 15,2963,15,835,15,2963,15,783,
.dw 2803,1491,2813,835,15,1491,15,783,
.dw 15,1491,2813,835,15,1491,15,783,
; Pattern 1:
.dw 2643,3971,4466,835,15,3971,15,783,
.dw 15,3971,15,783,15,3971,15,783,
.dw 3971,3971,2813,783,15,3971,15,783,
.dw 15,3971,2813,783,15,3971,15,815,
.dw 2643,3971,4466,835,15,3971,15,783,
.dw 15,3971,15,783,15,3971,15,783,
.dw 3971,3971,2813,783,15,3971,15,783,
.dw 2643,3971,2813,783,15,3971,15,783,
.dw 15,3971,4466,835,15,3971,15,783,
.dw 3971,3971,15,783,15,3971,15,783,
.dw 15,3971,2813,783,15,3971,15,783,
.dw 2499,3971,2813,783,15,3971,15,783,
.dw 2499,3971,4466,835,15,3971,15,783,
.dw 2499,3971,15,783,15,3971,15,783,
.dw 2643,3971,2813,783,15,3971,15,783,
.dw 15,3971,2813,783,15,3971,15,783,
.dw 2643,3971,4466,835,15,3971,15,783,
.dw 15,3971,15,783,15,3971,15,783,
.dw 3971,3971,2813,783,15,3971,15,783,
.dw 15,3971,2813,783,15,3971,15,783,
.dw 2643,3971,4466,835,15,3971,15,783,
.dw 15,3971,15,783,15,3971,15,783,
.dw 3971,3971,2813,783,15,3971,15,783,
.dw 2643,3971,2813,783,15,3971,15,783,
.dw 15,3971,4466,835,15,3971,15,783,
.dw 3971,3971,15,783,15,3971,15,783,
.dw 15,3971,2813,783,15,3971,15,783,
.dw 2499,3971,2813,835,15,3971,15,783,
.dw 2499,3971,1985,835,15,3971,15,783,
.dw 2499,3971,15,835,15,3971,15,783,
.dw 2643,1987,1985,835,15,1987,15,783,
.dw 15,1987,1985,835,15,1987,15,783,
; Pattern 2:
.dw 2963,2963,4466,835,15,2963,15,783,
.dw 15,2963,15,783,15,2963,15,783,
.dw 1491,2963,2813,783,15,2963,15,783,
.dw 15,2963,2813,783,15,2963,15,815,
.dw 2963,2963,4466,835,15,2963,15,783,
.dw 1987,2963,15,783,15,2963,15,783,
.dw 15,2963,2813,783,15,2963,15,783,
.dw 2963,2963,2813,783,15,2963,15,783,
.dw 1875,2963,4466,835,15,2963,15,783,
.dw 15,2963,15,783,15,2963,15,783,
.dw 2963,2963,2813,783,15,2963,15,783,
.dw 1987,2963,2813,783,15,2963,15,783,
.dw 15,2963,4466,835,15,2963,15,783,
.dw 1667,2963,15,783,15,2963,15,783,
.dw 1875,2963,2813,783,15,2963,15,783,
.dw 1987,2963,2813,783,15,2963,15,783,
.dw 2963,2963,4466,835,15,2963,15,783,
.dw 15,2963,15,783,15,2963,15,783,
.dw 1491,2963,2813,783,15,2963,15,783,
.dw 15,2963,2813,783,15,2963,15,783,
.dw 2963,2963,4466,835,15,2963,15,783,
.dw 1987,2963,15,783,15,2963,15,783,
.dw 15,2963,2813,783,15,2963,15,783,
.dw 2963,2963,2813,783,15,2963,15,783,
.dw 1875,2963,4466,835,15,2963,15,783,
.dw 15,2963,15,783,15,2963,15,783,
.dw 2963,2963,2813,783,15,2963,15,783,
.dw 1987,2963,2813,835,15,2963,15,783,
.dw 15,2963,4466,835,15,2963,15,783,
.dw 2499,2963,15,835,15,2963,15,783,
.dw 2643,1491,2813,835,15,1491,15,783,
.dw 2963,1491,2813,835,15,1491,15,783,
; Pattern 3:
.dw 3331,3971,4466,835,15,3971,15,783,
.dw 15,3971,15,783,15,3971,15,783,
.dw 1987,3971,2813,783,15,3971,15,783,
.dw 15,3971,2813,783,15,3971,15,815,
.dw 3331,3971,4466,835,15,3971,15,783,
.dw 2643,3971,15,783,15,3971,15,783,
.dw 15,3971,2813,783,15,3971,15,783,
.dw 3331,3971,2813,783,15,3971,15,783,
.dw 2499,3971,4466,835,15,3971,15,783,
.dw 15,3971,15,783,15,3971,15,783,
.dw 3331,3971,2813,783,15,3971,15,783,
.dw 2643,3971,2813,783,15,3971,15,783,
.dw 15,3971,4466,835,15,3971,15,783,
.dw 2227,3971,15,783,15,3971,15,783,
.dw 2499,3971,2813,783,15,3971,15,783,
.dw 2643,3971,2813,783,15,3971,15,783,
.dw 3331,3971,4466,835,15,3971,15,783,
.dw 15,3971,15,783,15,3971,15,783,
.dw 1987,3971,2813,783,15,3971,15,783,
.dw 15,3971,2813,783,15,3971,15,783,
.dw 3331,3971,4466,835,15,3971,15,783,
.dw 2643,3971,15,783,15,3971,15,783,
.dw 15,3971,2813,783,15,3971,15,783,
.dw 3331,3971,2813,783,15,3971,15,783,
.dw 2499,3971,4466,835,15,3971,15,783,
.dw 15,3971,15,783,15,3971,15,783,
.dw 3331,3971,2813,783,15,3971,15,783,
.dw 2643,3971,2813,835,15,3971,15,783,
.dw 15,3971,1985,835,15,3971,15,783,
.dw 1667,3971,15,835,15,3971,15,783,
.dw 1763,1987,1985,835,15,1987,15,783,
.dw 1987,1987,1985,835,15,1987,15,783,
; Pattern 4:
.dw 2963,2963,4466,835,2963,2963,15,783,
.dw 2967,2963,15,783,2967,2963,15,783,
.dw 1491,2963,2813,783,1491,2963,15,783,
.dw 1495,2963,2813,783,1495,2963,15,815,
.dw 2963,2963,4466,835,2963,2963,15,783,
.dw 1987,2963,15,783,1987,2963,15,783,
.dw 1991,2963,2813,783,1991,2963,15,783,
.dw 2963,2963,2813,783,2963,2963,15,783,
.dw 1875,2963,4466,835,1875,2963,15,783,
.dw 1879,2963,15,783,1879,2963,15,783,
.dw 2963,2963,2813,783,2963,2963,15,783,
.dw 1987,2963,2813,783,1987,2963,15,783,
.dw 1991,2963,4466,835,1991,2963,15,783,
.dw 1667,2963,15,783,1667,2963,15,783,
.dw 1875,2963,2813,783,1875,2963,15,783,
.dw 1987,2963,2813,783,1987,2963,15,783,
.dw 2963,2963,4466,835,2963,2963,15,783,
.dw 2967,2963,15,783,2967,2963,15,783,
.dw 1491,2963,2813,783,1491,2963,15,783,
.dw 1495,2963,2813,783,1495,2963,15,783,
.dw 2963,2963,4466,835,2963,2963,15,783,
.dw 1987,2963,15,783,1987,2963,15,783,
.dw 1991,2963,2813,783,1991,2963,15,783,
.dw 2963,2963,2813,783,2963,2963,15,783,
.dw 1875,2963,4466,835,1875,2963,15,783,
.dw 1879,2963,15,783,1879,2963,15,783,
.dw 2963,2963,2813,783,2963,2963,15,783,
.dw 1987,2963,2813,835,1987,2963,15,783,
.dw 1991,2963,4466,835,1991,2963,15,783,
.dw 2499,2963,15,835,2499,2963,15,783,
.dw 2643,1491,2813,835,2643,1491,15,783,
.dw 2963,1491,2813,835,2963,1491,15,783,
; Pattern 5:
.dw 3331,3971,4466,835,3331,3971,15,783,
.dw 3335,3971,15,783,3335,3971,15,783,
.dw 1987,3971,2813,783,1987,3971,15,783,
.dw 1991,3971,2813,783,1991,3971,15,815,
.dw 3331,3971,4466,835,3331,3971,15,783,
.dw 2643,3971,15,783,2643,3971,15,783,
.dw 2647,3971,2813,783,2647,3971,15,783,
.dw 3331,3971,2813,783,3331,3971,15,783,
.dw 2499,3971,4466,835,2499,3971,15,783,
.dw 2503,3971,15,783,2503,3971,15,783,
.dw 3331,3971,2813,783,3331,3971,15,783,
.dw 2643,3971,2813,783,2643,3971,15,783,
.dw 2647,3971,4466,835,2647,3971,15,783,
.dw 2227,3971,15,783,2227,3971,15,783,
.dw 2499,3971,2813,783,2499,3971,15,783,
.dw 2643,3971,2813,783,2643,3971,15,783,
.dw 3331,3971,4466,835,3331,3971,15,783,
.dw 3335,3971,15,783,3335,3971,15,783,
.dw 1987,3971,2813,783,1987,3971,15,783,
.dw 1991,3971,2813,783,1991,3971,15,783,
.dw 3331,3971,4466,835,3331,3971,15,783,
.dw 2643,3971,15,783,2643,3971,15,783,
.dw 2647,3971,2813,783,2647,3971,15,783,
.dw 3331,3971,2813,783,3331,3971,15,783,
.dw 2499,3971,4466,835,2499,3971,15,783,
.dw 2503,3971,15,783,2503,3971,15,783,
.dw 3331,3971,2813,783,3331,3971,15,783,
.dw 2643,3971,2813,835,2643,3971,15,783,
.dw 2647,3971,1985,835,2647,3971,15,783,
.dw 1667,3971,15,835,1667,3971,15,783,
.dw 1875,1987,1985,835,1875,1987,15,783,
.dw 1987,1987,1985,835,1987,1987,15,783,
; Pattern 6:
.dw 2803,2803,4466,835,15,2803,15,783,
.dw 15,2803,15,783,15,2803,15,783,
.dw 2643,2803,2813,783,15,2803,15,783,
.dw 15,2803,2813,783,15,2803,15,815,
.dw 2803,2803,4466,835,15,2803,15,783,
.dw 15,2803,15,783,15,2803,15,783,
.dw 2643,2803,2813,783,15,2803,15,783,
.dw 2803,2803,2813,783,15,2803,15,783,
.dw 15,2803,4466,835,15,2803,15,783,
.dw 2643,2803,15,783,15,2803,15,783,
.dw 15,2803,2813,783,15,2803,15,783,
.dw 2803,2803,2813,783,15,2803,15,783,
.dw 2803,2803,4466,835,15,2803,15,783,
.dw 15,2803,15,783,15,2803,15,783,
.dw 2643,2803,2813,783,15,2803,15,783,
.dw 15,2803,2813,783,15,2803,15,783,
.dw 2803,2803,4466,835,15,2803,15,783,
.dw 15,2803,15,783,15,2803,15,783,
.dw 2643,2803,2813,783,15,2803,15,783,
.dw 15,2803,2813,783,15,2803,15,783,
.dw 2803,2803,4466,835,15,2803,15,783,
.dw 15,2803,15,783,15,2803,15,783,
.dw 2643,2803,2813,783,15,2803,15,783,
.dw 2803,2803,2813,783,15,2803,15,783,
.dw 15,2803,4466,835,15,2803,15,783,
.dw 2643,2803,15,783,15,2803,15,783,
.dw 15,2803,2813,783,15,2803,15,783,
.dw 2803,2803,2813,835,15,2803,15,783,
.dw 2803,2803,4466,835,15,2803,15,783,
.dw 15,2803,15,835,15,2803,15,783,
.dw 2643,1395,2813,835,15,1395,15,783,
.dw 15,1395,2813,835,15,1395,15,783,
; Pattern 7:
.dw 2499,3747,4466,835,15,3747,15,783,
.dw 15,3747,15,783,15,3747,15,783,
.dw 3747,3747,2813,783,15,3747,15,783,
.dw 15,3747,2813,783,15,3747,15,815,
.dw 2499,3747,4466,835,15,3747,15,783,
.dw 15,3747,15,783,15,3747,15,783,
.dw 3747,3747,2813,783,15,3747,15,783,
.dw 2499,3747,2813,783,15,3747,15,783,
.dw 15,3747,4466,835,15,3747,15,783,
.dw 3747,3747,15,783,15,3747,15,783,
.dw 15,3747,2813,783,15,3747,15,783,
.dw 2355,3747,2813,783,15,3747,15,783,
.dw 2355,3747,4466,835,15,3747,15,783,
.dw 2355,3747,15,783,15,3747,15,783,
.dw 2499,3747,2813,783,15,3747,15,783,
.dw 15,3747,2813,783,15,3747,15,783,
.dw 2499,3747,4466,835,15,3747,15,783,
.dw 15,3747,15,783,15,3747,15,783,
.dw 3747,3747,2813,783,15,3747,15,783,
.dw 15,3747,2813,783,15,3747,15,783,
.dw 2499,3747,4466,835,15,3747,15,783,
.dw 15,3747,15,783,15,3747,15,783,
.dw 3747,3747,2813,783,15,3747,15,783,
.dw 2499,3747,2813,783,15,3747,15,783,
.dw 15,3747,4466,835,15,3747,15,783,
.dw 3747,3747,15,783,15,3747,15,783,
.dw 15,3747,2813,783,15,3747,15,783,
.dw 2499,3747,2813,835,15,3747,15,783,
.dw 2499,3747,1985,835,15,3747,15,783,
.dw 15,3747,15,835,15,3747,15,783,
.dw 3747,1875,1985,835,15,1875,15,783,
.dw 15,1875,1985,835,15,1875,15,783,
; Pattern 8:
.dw 2499,3747,4466,835,15,3747,15,783,
.dw 15,3747,15,783,15,3747,15,783,
.dw 2355,3747,2813,783,15,3747,15,783,
.dw 15,3747,2813,783,15,3747,15,815,
.dw 2499,3747,4466,835,15,3747,15,783,
.dw 15,3747,15,783,15,3747,15,783,
.dw 2355,3747,2813,783,15,3747,15,783,
.dw 2499,3747,2813,783,15,3747,15,783,
.dw 15,3747,4466,835,15,3747,15,783,
.dw 2355,3747,15,783,15,3747,15,783,
.dw 15,3747,2813,783,15,3747,15,783,
.dw 2499,3747,2813,783,15,3747,15,783,
.dw 2499,3747,4466,835,15,3747,15,783,
.dw 15,3747,15,783,15,3747,15,783,
.dw 2355,3747,2813,783,15,3747,15,783,
.dw 15,3747,2813,783,15,3747,15,783,
.dw 2499,3747,4466,835,15,3747,15,783,
.dw 15,3747,15,783,15,3747,15,783,
.dw 2355,3747,2813,783,15,3747,15,783,
.dw 15,3747,2813,783,15,3747,15,783,
.dw 2499,3747,4466,835,15,3747,15,783,
.dw 15,3747,15,783,15,3747,15,783,
.dw 2355,3747,2813,783,15,3747,15,783,
.dw 2499,3747,2813,783,15,3747,15,783,
.dw 15,3747,4466,835,15,3747,15,783,
.dw 2355,3747,15,783,15,3747,15,783,
.dw 15,3747,2813,783,15,3747,15,783,
.dw 2355,3747,2813,835,15,3747,15,783,
.dw 2355,3747,1985,835,15,3747,15,783,
.dw 2355,3747,15,835,15,3747,15,783,
.dw 2499,1875,1985,835,15,1875,15,783,
.dw 15,1875,1985,835,15,1875,15,783,
; Pattern 9:
.dw 2803,2803,4466,835,15,2803,15,783,
.dw 15,2803,15,783,15,2803,15,783,
.dw 1395,2803,2813,783,15,2803,15,783,
.dw 15,2803,2813,783,15,2803,15,815,
.dw 2803,2803,4466,835,15,2803,15,783,
.dw 1875,2803,15,783,15,2803,15,783,
.dw 15,2803,2813,783,15,2803,15,783,
.dw 2803,2803,2813,783,15,2803,15,783,
.dw 1763,2803,4466,835,15,2803,15,783,
.dw 15,2803,15,783,15,2803,15,783,
.dw 2803,2803,2813,783,15,2803,15,783,
.dw 1875,2803,2813,783,15,2803,15,783,
.dw 15,2803,4466,835,15,2803,15,783,
.dw 1571,2803,15,783,15,2803,15,783,
.dw 1763,2803,2813,783,15,2803,15,783,
.dw 1875,2803,2813,783,15,2803,15,783,
.dw 2803,2803,4466,835,15,2803,15,783,
.dw 15,2803,15,783,15,2803,15,783,
.dw 1395,2803,2813,783,15,2803,15,783,
.dw 15,2803,2813,783,15,2803,15,783,
.dw 2803,2803,4466,835,15,2803,15,783,
.dw 1875,2803,15,783,15,2803,15,783,
.dw 15,2803,2813,783,15,2803,15,783,
.dw 2803,2803,2813,783,15,2803,15,783,
.dw 1763,2803,4466,835,15,2803,15,783,
.dw 15,2803,15,783,15,2803,15,783,
.dw 2803,2803,2813,783,15,2803,15,783,
.dw 1875,2803,2813,835,15,2803,15,783,
.dw 15,2803,4466,835,15,2803,15,783,
.dw 2355,2803,15,835,15,2803,15,783,
.dw 2499,1395,2813,835,15,1395,15,783,
.dw 2803,1395,2813,835,15,1395,15,783,
; Pattern 10:
.dw 3139,3747,4466,835,15,3747,15,783,
.dw 15,3747,15,783,15,3747,15,783,
.dw 1875,3747,2813,783,15,3747,15,783,
.dw 15,3747,2813,783,15,3747,15,815,
.dw 3139,3747,4466,835,15,3747,15,783,
.dw 2499,3747,15,783,15,3747,15,783,
.dw 15,3747,2813,783,15,3747,15,783,
.dw 3139,3747,2813,783,15,3747,15,783,
.dw 2355,3747,4466,835,15,3747,15,783,
.dw 15,3747,15,783,15,3747,15,783,
.dw 3139,3747,2813,783,15,3747,15,783,
.dw 2499,3747,2813,783,15,3747,15,783,
.dw 15,3747,4466,835,15,3747,15,783,
.dw 2099,3747,15,783,15,3747,15,783,
.dw 2355,3747,2813,783,15,3747,15,783,
.dw 2499,3747,2813,783,15,3747,15,783,
.dw 3139,3747,4466,835,15,3747,15,783,
.dw 15,3747,15,783,15,3747,15,783,
.dw 1875,3747,2813,783,15,3747,15,783,
.dw 15,3747,2813,783,15,3747,15,783,
.dw 3139,3747,4466,835,15,3747,15,783,
.dw 2499,3747,15,783,15,3747,15,783,
.dw 15,3747,2813,783,15,3747,15,783,
.dw 3139,3747,2813,783,15,3747,15,783,
.dw 2355,3747,4466,835,15,3747,15,783,
.dw 15,3747,15,783,15,3747,15,783,
.dw 3139,3747,2813,783,15,3747,15,783,
.dw 2499,3747,2813,835,15,3747,15,783,
.dw 15,3747,1985,835,15,3747,15,783,
.dw 1571,3747,15,835,15,3747,15,783,
.dw 1667,1875,1985,835,15,1875,15,783,
.dw 1875,1875,1985,835,15,1875,15,783,
; Pattern 11:
.dw 2803,2803,4466,835,2803,2803,15,783,
.dw 2807,2803,15,783,2807,2803,15,783,
.dw 1395,2803,2813,783,1395,2803,15,783,
.dw 1399,2803,2813,783,1399,2803,15,815,
.dw 2803,2803,4466,835,2803,2803,15,783,
.dw 1875,2803,15,783,1875,2803,15,783,
.dw 1879,2803,2813,783,1879,2803,15,783,
.dw 2803,2803,2813,783,2803,2803,15,783,
.dw 1763,2803,4466,835,1763,2803,15,783,
.dw 1767,2803,15,783,1767,2803,15,783,
.dw 2803,2803,2813,783,2803,2803,15,783,
.dw 1875,2803,2813,783,1875,2803,15,783,
.dw 1879,2803,4466,835,1879,2803,15,783,
.dw 1571,2803,15,783,1571,2803,15,783,
.dw 1763,2803,2813,783,1763,2803,15,783,
.dw 1875,2803,2813,783,1875,2803,15,783,
.dw 2803,2803,4466,835,2803,2803,15,783,
.dw 2807,2803,15,783,2807,2803,15,783,
.dw 1395,2803,2813,783,1395,2803,15,783,
.dw 1399,2803,2813,783,1399,2803,15,783,
.dw 2803,2803,4466,835,2803,2803,15,783,
.dw 1875,2803,15,783,1875,2803,15,783,
.dw 1879,2803,2813,783,1879,2803,15,783,
.dw 2803,2803,2813,783,2803,2803,15,783,
.dw 1763,2803,4466,835,1763,2803,15,783,
.dw 1767,2803,15,783,1767,2803,15,783,
.dw 2803,2803,2813,783,2803,2803,15,783,
.dw 1875,2803,2813,835,1875,2803,15,783,
.dw 1879,2803,4466,835,1879,2803,15,783,
.dw 2355,2803,15,835,2355,2803,15,783,
.dw 2499,1395,2813,835,2499,1395,15,783,
.dw 2803,1395,2813,835,2803,1395,15,783,
; Pattern 12:
.dw 3139,3747,4466,835,3139,3747,15,783,
.dw 3143,3747,15,783,3143,3747,15,783,
.dw 1875,3747,2813,783,1875,3747,15,783,
.dw 1879,3747,2813,783,1879,3747,15,815,
.dw 3139,3747,4466,835,3139,3747,15,783,
.dw 2499,3747,15,783,2499,3747,15,783,
.dw 2503,3747,2813,783,2503,3747,15,783,
.dw 3139,3747,2813,783,3139,3747,15,783,
.dw 2355,3747,4466,835,2355,3747,15,783,
.dw 2359,3747,15,783,2359,3747,15,783,
.dw 3139,3747,2813,783,3139,3747,15,783,
.dw 2499,3747,2813,783,2499,3747,15,783,
.dw 2503,3747,4466,835,2503,3747,15,783,
.dw 2099,3747,15,783,2099,3747,15,783,
.dw 2355,3747,2813,783,2355,3747,15,783,
.dw 2499,3747,2813,783,2499,3747,15,783,
.dw 3139,3747,4466,835,3139,3747,15,783,
.dw 3143,3747,15,783,3143,3747,15,783,
.dw 1875,3747,2813,783,1875,3747,15,783,
.dw 1879,3747,2813,783,1879,3747,15,783,
.dw 3139,3747,4466,835,3139,3747,15,783,
.dw 2499,3747,15,783,2499,3747,15,783,
.dw 2503,3747,2813,783,2503,3747,15,783,
.dw 3139,3747,2813,783,3139,3747,15,783,
.dw 2355,3747,4466,835,2355,3747,15,783,
.dw 2359,3747,15,783,2359,3747,15,783,
.dw 3139,3747,2813,783,3139,3747,15,783,
.dw 2499,3747,2813,835,2499,3747,15,783,
.dw 2503,3747,1985,835,2503,3747,15,783,
.dw 1571,3747,15,835,1571,3747,15,783,
.dw 1667,1875,1985,835,1667,1875,15,783,
.dw 1875,1875,1985,835,1875,1875,15,783,
; Pattern 13:
.dw 2643,2643,4466,835,15,2643,15,783,
.dw 15,2643,15,783,15,2643,15,783,
.dw 2499,2643,2813,783,15,2643,15,783,
.dw 15,2643,2813,783,15,2643,15,815,
.dw 2643,2643,4466,835,15,2643,15,783,
.dw 15,2643,15,783,15,2643,15,783,
.dw 2499,2643,2813,783,15,2643,15,783,
.dw 2643,2643,2813,783,15,2643,15,783,
.dw 15,2643,4466,835,15,2643,15,783,
.dw 2499,2643,15,783,15,2643,15,783,
.dw 15,2643,2813,783,15,2643,15,783,
.dw 2643,2643,2813,783,15,2643,15,783,
.dw 2643,2643,4466,835,15,2643,15,783,
.dw 15,2643,15,783,15,2643,15,783,
.dw 2499,2643,2813,783,15,2643,15,783,
.dw 15,2643,2813,783,15,2643,15,783,
.dw 2643,2643,4466,835,15,2643,15,783,
.dw 15,2643,15,783,15,2643,15,783,
.dw 2499,2643,2813,783,15,2643,15,783,
.dw 15,2643,2813,783,15,2643,15,783,
.dw 2643,2643,4466,835,15,2643,15,783,
.dw 15,2643,15,783,15,2643,15,783,
.dw 2499,2643,2813,783,15,2643,15,783,
.dw 2643,2643,2813,783,15,2643,15,783,
.dw 15,2643,4466,835,15,2643,15,783,
.dw 2499,2643,15,783,15,2643,15,783,
.dw 15,2643,2813,783,15,2643,15,783,
.dw 2643,2643,2813,835,15,2643,15,783,
.dw 2643,2643,4466,835,15,2643,15,783,
.dw 15,2643,15,835,15,2643,15,783,
.dw 2499,1315,2813,835,15,1315,15,783,
.dw 15,1315,2813,835,15,1315,15,783,
; Pattern 14:
.dw 2355,3539,4466,835,15,3539,15,783,
.dw 15,3539,15,783,15,3539,15,783,
.dw 3539,3539,2813,783,15,3539,15,783,
.dw 15,3539,2813,783,15,3539,15,815,
.dw 2355,3539,4466,835,15,3539,15,783,
.dw 15,3539,15,783,15,3539,15,783,
.dw 3539,3539,2813,783,15,3539,15,783,
.dw 2355,3539,2813,783,15,3539,15,783,
.dw 15,3539,4466,835,15,3539,15,783,
.dw 3539,3539,15,783,15,3539,15,783,
.dw 15,3539,2813,783,15,3539,15,783,
.dw 2227,3539,2813,783,15,3539,15,783,
.dw 2227,3539,4466,835,15,3539,15,783,
.dw 2227,3539,15,783,15,3539,15,783,
.dw 2355,3539,2813,783,15,3539,15,783,
.dw 15,3539,2813,783,15,3539,15,783,
.dw 2355,3539,4466,835,15,3539,15,783,
.dw 15,3539,15,783,15,3539,15,783,
.dw 3539,3539,2813,783,15,3539,15,783,
.dw 15,3539,2813,783,15,3539,15,783,
.dw 2355,3539,4466,835,15,3539,15,783,
.dw 15,3539,15,783,15,3539,15,783,
.dw 3539,3539,2813,783,15,3539,15,783,
.dw 2355,3539,2813,783,15,3539,15,783,
.dw 15,3539,4466,835,15,3539,15,783,
.dw 3539,3539,15,783,15,3539,15,783,
.dw 15,3539,2813,783,15,3539,15,783,
.dw 2355,3539,2813,835,15,3539,15,783,
.dw 2355,3539,1985,835,15,3539,15,783,
.dw 15,3539,15,835,15,3539,15,783,
.dw 3539,1763,1985,835,15,1763,15,783,
.dw 15,1763,1985,835,15,1763,15,783,
; Pattern 15:
.dw 2355,3539,4466,835,15,3539,15,783,
.dw 15,3539,15,783,15,3539,15,783,
.dw 2227,3539,2813,783,15,3539,15,783,
.dw 15,3539,2813,783,15,3539,15,815,
.dw 2355,3539,4466,835,15,3539,15,783,
.dw 15,3539,15,783,15,3539,15,783,
.dw 2227,3539,2813,783,15,3539,15,783,
.dw 2355,3539,2813,783,15,3539,15,783,
.dw 15,3539,4466,835,15,3539,15,783,
.dw 2227,3539,15,783,15,3539,15,783,
.dw 15,3539,2813,783,15,3539,15,783,
.dw 2355,3539,2813,783,15,3539,15,783,
.dw 2355,3539,4466,835,15,3539,15,783,
.dw 15,3539,15,783,15,3539,15,783,
.dw 2227,3539,2813,783,15,3539,15,783,
.dw 15,3539,2813,783,15,3539,15,783,
.dw 2355,3539,4466,835,15,3539,15,783,
.dw 15,3539,15,783,15,3539,15,783,
.dw 2227,3539,2813,783,15,3539,15,783,
.dw 15,3539,2813,783,15,3539,15,783,
.dw 2355,3539,4466,835,15,3539,15,783,
.dw 15,3539,15,783,15,3539,15,783,
.dw 2227,3539,2813,783,15,3539,15,783,
.dw 2355,3539,2813,783,15,3539,15,783,
.dw 15,3539,4466,835,15,3539,15,783,
.dw 2227,3539,15,783,15,3539,15,783,
.dw 15,3539,2813,783,15,3539,15,783,
.dw 2227,3539,2813,835,15,3539,15,783,
.dw 2227,3539,1985,835,15,3539,15,783,
.dw 2227,3539,15,835,15,3539,15,783,
.dw 2355,1763,1985,835,15,1763,15,783,
.dw 15,1763,1985,835,15,1763,15,783,
; Pattern 16:
.dw 2643,2643,4466,835,15,2643,15,783,
.dw 15,2643,15,783,15,2643,15,783,
.dw 1315,2643,2813,783,15,2643,15,783,
.dw 15,2643,2813,783,15,2643,15,815,
.dw 2643,2643,4466,835,15,2643,15,783,
.dw 1763,2643,15,783,15,2643,15,783,
.dw 15,2643,2813,783,15,2643,15,783,
.dw 2643,2643,2813,783,15,2643,15,783,
.dw 1667,2643,4466,835,15,2643,15,783,
.dw 15,2643,15,783,15,2643,15,783,
.dw 2643,2643,2813,783,15,2643,15,783,
.dw 1763,2643,2813,783,15,2643,15,783,
.dw 15,2643,4466,835,15,2643,15,783,
.dw 1491,2643,15,783,15,2643,15,783,
.dw 1667,2643,2813,783,15,2643,15,783,
.dw 1763,2643,2813,783,15,2643,15,783,
.dw 2643,2643,4466,835,15,2643,15,783,
.dw 15,2643,15,783,15,2643,15,783,
.dw 1315,2643,2813,783,15,2643,15,783,
.dw 15,2643,2813,783,15,2643,15,783,
.dw 2643,2643,4466,835,15,2643,15,783,
.dw 1763,2643,15,783,15,2643,15,783,
.dw 15,2643,2813,783,15,2643,15,783,
.dw 2643,2643,2813,783,15,2643,15,783,
.dw 1667,2643,4466,835,15,2643,15,783,
.dw 15,2643,15,783,15,2643,15,783,
.dw 2643,2643,2813,783,15,2643,15,783,
.dw 1763,2643,2813,835,15,2643,15,783,
.dw 15,2643,4466,835,15,2643,15,783,
.dw 2227,2643,15,835,15,2643,15,783,
.dw 2355,1315,2813,835,15,1315,15,783,
.dw 2643,1315,2813,835,15,1315,15,783,
; Pattern 17:
.dw 2963,3539,4466,835,15,3539,15,783,
.dw 15,3539,15,783,15,3539,15,783,
.dw 1763,3539,2813,783,15,3539,15,783,
.dw 15,3539,2813,783,15,3539,15,815,
.dw 2963,3539,4466,835,15,3539,15,783,
.dw 2355,3539,15,783,15,3539,15,783,
.dw 15,3539,2813,783,15,3539,15,783,
.dw 2963,3539,2813,783,15,3539,15,783,
.dw 2227,3539,4466,835,15,3539,15,783,
.dw 15,3539,15,783,15,3539,15,783,
.dw 2963,3539,2813,783,15,3539,15,783,
.dw 2355,3539,2813,783,15,3539,15,783,
.dw 15,3539,4466,835,15,3539,15,783,
.dw 1987,3539,15,783,15,3539,15,783,
.dw 2227,3539,2813,783,15,3539,15,783,
.dw 2355,3539,2813,783,15,3539,15,783,
.dw 2963,3539,4466,835,15,3539,15,783,
.dw 15,3539,15,783,15,3539,15,783,
.dw 1763,3539,2813,783,15,3539,15,783,
.dw 15,3539,2813,783,15,3539,15,783,
.dw 2963,3539,4466,835,15,3539,15,783,
.dw 2355,3539,15,783,15,3539,15,783,
.dw 15,3539,2813,783,15,3539,15,783,
.dw 2963,3539,2813,783,15,3539,15,783,
.dw 2227,3539,4466,835,15,3539,15,783,
.dw 15,3539,15,783,15,3539,15,783,
.dw 2963,3539,2813,783,15,3539,15,783,
.dw 2355,3539,2813,835,15,3539,15,783,
.dw 15,3539,1985,835,15,3539,15,783,
.dw 1491,3539,15,835,15,3539,15,783,
.dw 1571,1763,1985,835,15,1763,15,783,
.dw 1763,1763,1985,835,15,1763,15,783,
; Pattern 18:
.dw 2643,2643,4466,835,2643,2643,15,783,
.dw 2647,2643,15,783,2647,2643,15,783,
.dw 1315,2643,2813,783,1315,2643,15,783,
.dw 1319,2643,2813,783,1319,2643,15,815,
.dw 2643,2643,4466,835,2643,2643,15,783,
.dw 1763,2643,15,783,1763,2643,15,783,
.dw 1767,2643,2813,783,1767,2643,15,783,
.dw 2643,2643,2813,783,2643,2643,15,783,
.dw 1667,2643,4466,835,1667,2643,15,783,
.dw 1671,2643,15,783,1671,2643,15,783,
.dw 2643,2643,2813,783,2643,2643,15,783,
.dw 1763,2643,2813,783,1763,2643,15,783,
.dw 1767,2643,4466,835,1767,2643,15,783,
.dw 1491,2643,15,783,1491,2643,15,783,
.dw 1667,2643,2813,783,1667,2643,15,783,
.dw 1763,2643,2813,783,1763,2643,15,783,
.dw 2643,2643,4466,835,2643,2643,15,783,
.dw 2647,2643,15,783,2647,2643,15,783,
.dw 1315,2643,2813,783,1315,2643,15,783,
.dw 1319,2643,2813,783,1319,2643,15,783,
.dw 2643,2643,4466,835,2643,2643,15,783,
.dw 1763,2643,15,783,1763,2643,15,783,
.dw 1767,2643,2813,783,1767,2643,15,783,
.dw 2643,2643,2813,783,2643,2643,15,783,
.dw 1667,2643,4466,835,1667,2643,15,783,
.dw 1671,2643,15,783,1671,2643,15,783,
.dw 2643,2643,2813,783,2643,2643,15,783,
.dw 1763,2643,2813,835,1763,2643,15,783,
.dw 1767,2643,4466,835,1767,2643,15,783,
.dw 2227,2643,15,835,2227,2643,15,783,
.dw 2355,1315,2813,835,2355,1315,15,783,
.dw 2643,1315,2813,835,2643,1315,15,783,
; Pattern 19:
.dw 2963,3539,4466,835,2963,3539,15,783,
.dw 2967,3539,15,783,2967,3539,15,783,
.dw 1763,3539,2813,783,1763,3539,15,783,
.dw 1767,3539,2813,783,1767,3539,15,815,
.dw 2963,3539,4466,835,2963,3539,15,783,
.dw 2355,3539,15,783,2355,3539,15,783,
.dw 2359,3539,2813,783,2359,3539,15,783,
.dw 2963,3539,2813,783,2963,3539,15,783,
.dw 2227,3539,4466,835,2227,3539,15,783,
.dw 2231,3539,15,783,2231,3539,15,783,
.dw 2963,3539,2813,783,2963,3539,15,783,
.dw 2355,3539,2813,783,2355,3539,15,783,
.dw 2359,3539,4466,835,2359,3539,15,783,
.dw 1987,3539,15,783,1987,3539,15,783,
.dw 2227,3539,2813,783,2227,3539,15,783,
.dw 2355,3539,2813,783,2355,3539,15,783,
.dw 2963,3539,4466,835,2963,3539,15,783,
.dw 2967,3539,15,783,2967,3539,15,783,
.dw 1763,3539,2813,783,1763,3539,15,783,
.dw 1767,3539,2813,783,1767,3539,15,783,
.dw 2963,3539,4466,835,2963,3539,15,783,
.dw 2355,3539,15,783,2355,3539,15,783,
.dw 2359,3539,2813,783,2359,3539,15,783,
.dw 2963,3539,2813,783,2963,3539,15,783,
.dw 2227,3539,4466,835,2227,3539,15,783,
.dw 2231,3539,15,783,2231,3539,15,783,
.dw 2963,3539,2813,783,2963,3539,15,783,
.dw 2355,3539,2813,835,2355,3539,15,783,
.dw 2359,3539,1985,835,2359,3539,15,783,
.dw 1491,3539,15,835,1491,3539,15,783,
.dw 1571,1763,1985,835,1571,1763,15,783,
.dw 1763,1763,1985,835,1763,1763,15,783,
; Pattern 20:
.dw 2499,2499,4466,835,15,2499,15,783,
.dw 15,2499,15,783,15,2499,15,783,
.dw 2355,2499,2813,783,15,2499,15,783,
.dw 15,2499,2813,783,15,2499,15,815,
.dw 2499,2499,4466,835,15,2499,15,783,
.dw 15,2499,15,783,15,2499,15,783,
.dw 2355,2499,2813,783,15,2499,15,783,
.dw 2499,2499,2813,783,15,2499,15,783,
.dw 15,2499,4466,835,15,2499,15,783,
.dw 2355,2499,15,783,15,2499,15,783,
.dw 15,2499,2813,783,15,2499,15,783,
.dw 2499,2499,2813,783,15,2499,15,783,
.dw 2499,2499,4466,835,15,2499,15,783,
.dw 15,2499,15,783,15,2499,15,783,
.dw 2355,2499,2813,783,15,2499,15,783,
.dw 15,2499,2813,783,15,2499,15,783,
.dw 2499,2499,4466,835,15,2499,15,783,
.dw 15,2499,15,783,15,2499,15,783,
.dw 2355,2499,2813,783,15,2499,15,783,
.dw 15,2499,2813,783,15,2499,15,783,
.dw 2499,2499,4466,835,15,2499,15,783,
.dw 15,2499,15,783,15,2499,15,783,
.dw 2355,2499,2813,783,15,2499,15,783,
.dw 2499,2499,2813,783,15,2499,15,783,
.dw 15,2499,4466,835,15,2499,15,783,
.dw 2355,2499,15,783,15,2499,15,783,
.dw 15,2499,2813,783,15,2499,15,783,
.dw 2499,2499,2813,835,15,2499,15,783,
.dw 2499,2499,4466,835,15,2499,15,783,
.dw 15,2499,15,835,15,2499,15,783,
.dw 2355,1251,2813,835,15,1251,15,783,
.dw 15,1251,2813,835,15,1251,15,783,
; Pattern 21:
.dw 2227,3331,4466,835,15,3331,15,783,
.dw 15,3331,15,783,15,3331,15,783,
.dw 3331,3331,2813,783,15,3331,15,783,
.dw 15,3331,2813,783,15,3331,15,815,
.dw 2227,3331,4466,835,15,3331,15,783,
.dw 15,3331,15,783,15,3331,15,783,
.dw 3331,3331,2813,783,15,3331,15,783,
.dw 2227,3331,2813,783,15,3331,15,783,
.dw 15,3331,4466,835,15,3331,15,783,
.dw 3331,3331,15,783,15,3331,15,783,
.dw 15,3331,2813,783,15,3331,15,783,
.dw 2099,3331,2813,783,15,3331,15,783,
.dw 2099,3331,4466,835,15,3331,15,783,
.dw 2099,3331,15,783,15,3331,15,783,
.dw 2227,3331,2813,783,15,3331,15,783,
.dw 15,3331,2813,783,15,3331,15,783,
.dw 2227,3331,4466,835,15,3331,15,783,
.dw 15,3331,15,783,15,3331,15,783,
.dw 3331,3331,2813,783,15,3331,15,783,
.dw 15,3331,2813,783,15,3331,15,783,
.dw 2227,3331,4466,835,15,3331,15,783,
.dw 15,3331,15,783,15,3331,15,783,
.dw 3331,3331,2813,783,15,3331,15,783,
.dw 2227,3331,2813,783,15,3331,15,783,
.dw 15,3331,4466,835,15,3331,15,783,
.dw 3331,3331,15,783,15,3331,15,783,
.dw 15,3331,2813,783,15,3331,15,783,
.dw 2099,3331,2813,835,15,3331,15,783,
.dw 2099,3331,1985,835,15,3331,15,783,
.dw 2099,3331,15,835,15,3331,15,783,
.dw 2227,1667,1985,835,15,1667,15,783,
.dw 15,1667,1985,835,15,1667,15,783,
; Pattern 22:
.dw 2227,3331,4466,835,15,3331,15,783,
.dw 15,3331,15,783,15,3331,15,783,
.dw 2099,3331,2813,783,15,3331,15,783,
.dw 15,3331,2813,783,15,3331,15,815,
.dw 2227,3331,4466,835,15,3331,15,783,
.dw 15,3331,15,783,15,3331,15,783,
.dw 2099,3331,2813,783,15,3331,15,783,
.dw 2227,3331,2813,783,15,3331,15,783,
.dw 15,3331,4466,835,15,3331,15,783,
.dw 2099,3331,15,783,15,3331,15,783,
.dw 15,3331,2813,783,15,3331,15,783,
.dw 2227,3331,2813,783,15,3331,15,783,
.dw 2227,3331,4466,835,15,3331,15,783,
.dw 15,3331,15,783,15,3331,15,783,
.dw 2099,3331,2813,783,15,3331,15,783,
.dw 15,3331,2813,783,15,3331,15,783,
.dw 2227,3331,4466,835,15,3331,15,783,
.dw 15,3331,15,783,15,3331,15,783,
.dw 2099,3331,2813,783,15,3331,15,783,
.dw 15,3331,2813,783,15,3331,15,783,
.dw 2227,3331,4466,835,15,3331,15,783,
.dw 15,3331,15,783,15,3331,15,783,
.dw 2099,3331,2813,783,15,3331,15,783,
.dw 2227,3331,2813,783,15,3331,15,783,
.dw 15,3331,4466,835,15,3331,15,783,
.dw 2099,3331,15,783,15,3331,15,783,
.dw 15,3331,2813,783,15,3331,15,783,
.dw 2227,3331,2813,835,15,3331,15,783,
.dw 2227,3331,1985,835,15,3331,15,783,
.dw 2227,3331,15,835,15,3331,15,783,
.dw 2099,1667,1985,835,15,1667,15,783,
.dw 15,1667,1985,835,15,1667,15,783,
; Pattern 23:
.dw 2499,2499,4466,835,15,2499,15,783,
.dw 15,2499,15,783,15,2499,15,783,
.dw 1252,2499,2813,783,15,2499,15,783,
.dw 15,2499,2813,783,15,2499,15,815,
.dw 2499,2499,4466,835,15,2499,15,783,
.dw 1667,2499,15,783,15,2499,15,783,
.dw 15,2499,2813,783,15,2499,15,783,
.dw 2499,2499,2813,783,15,2499,15,783,
.dw 1571,2499,4466,835,15,2499,15,783,
.dw 15,2499,15,783,15,2499,15,783,
.dw 2499,2499,2813,783,15,2499,15,783,
.dw 1667,2499,2813,783,15,2499,15,783,
.dw 15,2499,4466,835,15,2499,15,783,
.dw 1395,2499,15,783,15,2499,15,783,
.dw 1571,2499,2813,783,15,2499,15,783,
.dw 1667,2499,2813,783,15,2499,15,783,
.dw 2499,2499,4466,835,15,2499,15,783,
.dw 15,2499,15,783,15,2499,15,783,
.dw 1252,2499,2813,783,15,2499,15,783,
.dw 15,2499,2813,783,15,2499,15,783,
.dw 2499,2499,4466,835,15,2499,15,783,
.dw 1667,2499,15,783,15,2499,15,783,
.dw 15,2499,2813,783,15,2499,15,783,
.dw 2499,2499,2813,783,15,2499,15,783,
.dw 1571,2499,4466,835,15,2499,15,783,
.dw 15,2499,15,783,15,2499,15,783,
.dw 2499,2499,2813,783,15,2499,15,783,
.dw 1667,2499,2813,835,15,2499,15,783,
.dw 15,2499,4466,835,15,2499,15,783,
.dw 2099,2499,15,835,15,2499,15,783,
.dw 2227,1251,2813,835,15,1251,15,783,
.dw 2499,1251,2813,835,15,1251,15,783,
; Pattern 24:
.dw 2803,3331,4466,835,15,3331,15,783,
.dw 15,3331,15,783,15,3331,15,783,
.dw 1667,3331,2813,783,15,3331,15,783,
.dw 15,3331,2813,783,15,3331,15,815,
.dw 2803,3331,4466,835,15,3331,15,783,
.dw 2227,3331,15,783,15,3331,15,783,
.dw 15,3331,2813,783,15,3331,15,783,
.dw 2803,3331,2813,783,15,3331,15,783,
.dw 2099,3331,4466,835,15,3331,15,783,
.dw 15,3331,15,783,15,3331,15,783,
.dw 2803,3331,2813,783,15,3331,15,783,
.dw 2227,3331,2813,783,15,3331,15,783,
.dw 15,3331,4466,835,15,3331,15,783,
.dw 1875,3331,15,783,15,3331,15,783,
.dw 2099,3331,2813,783,15,3331,15,783,
.dw 2227,3331,2813,783,15,3331,15,783,
.dw 2803,3331,4466,835,15,3331,15,783,
.dw 15,3331,15,783,15,3331,15,783,
.dw 1667,3331,2813,783,15,3331,15,783,
.dw 15,3331,2813,783,15,3331,15,783,
.dw 2803,3331,4466,835,15,3331,15,783,
.dw 2227,3331,15,783,15,3331,15,783,
.dw 15,3331,2813,783,15,3331,15,783,
.dw 2803,3331,2813,783,15,3331,15,783,
.dw 2099,3331,4466,835,15,3331,15,783,
.dw 15,3331,15,783,15,3331,15,783,
.dw 2803,3331,2813,783,15,3331,15,783,
.dw 2227,3331,2813,835,15,3331,15,783,
.dw 15,3331,1985,835,15,3331,15,783,
.dw 1875,3331,15,835,15,3331,15,783,
.dw 2099,1667,1985,835,15,1667,15,783,
.dw 2227,1667,1985,835,15,1667,15,783,
; Pattern 25:
.dw 2499,2499,4466,835,2499,2499,15,783,
.dw 2503,2499,15,783,2503,2499,15,783,
.dw 1251,2499,2813,783,1251,2499,15,783,
.dw 1255,2499,2813,783,1255,2499,15,815,
.dw 2499,2499,4466,835,2499,2499,15,783,
.dw 1667,2499,15,783,1667,2499,15,783,
.dw 1671,2499,2813,783,1671,2499,15,783,
.dw 2499,2499,2813,783,2499,2499,15,783,
.dw 1571,2499,4466,835,1571,2499,15,783,
.dw 1575,2499,15,783,1575,2499,15,783,
.dw 2499,2499,2813,783,2499,2499,15,783,
.dw 1667,2499,2813,783,1667,2499,15,783,
.dw 1671,2499,4466,835,1671,2499,15,783,
.dw 1395,2499,15,783,1395,2499,15,783,
.dw 1571,2499,2813,783,1571,2499,15,783,
.dw 1667,2499,2813,783,1667,2499,15,783,
.dw 2499,2499,4466,835,2499,2499,15,783,
.dw 2503,2499,15,783,2503,2499,15,783,
.dw 1251,2499,2813,783,1251,2499,15,783,
.dw 1255,2499,2813,783,1255,2499,15,783,
.dw 2499,2499,4466,835,2499,2499,15,783,
.dw 1667,2499,15,783,1667,2499,15,783,
.dw 1671,2499,2813,783,1671,2499,15,783,
.dw 2499,2499,2813,783,2499,2499,15,783,
.dw 1571,2499,4466,835,1571,2499,15,783,
.dw 1575,2499,15,783,1575,2499,15,783,
.dw 2499,2499,2813,783,2499,2499,15,783,
.dw 1667,2499,2813,835,1667,2499,15,783,
.dw 1671,2499,4466,835,1671,2499,15,783,
.dw 2099,2499,15,835,2099,2499,15,783,
.dw 2227,1251,2813,835,2227,1251,15,783,
.dw 2499,1251,2813,835,2499,1251,15,783,
; Pattern 26:
.dw 2803,3331,4466,835,2803,3331,15,783,
.dw 2807,3331,15,783,2807,3331,15,783,
.dw 1667,3331,2813,783,1667,3331,15,783,
.dw 1671,3331,2813,783,1671,3331,15,815,
.dw 2803,3331,4466,835,2803,3331,15,783,
.dw 2227,3331,15,783,2227,3331,15,783,
.dw 2231,3331,2813,783,2231,3331,15,783,
.dw 2803,3331,2813,783,2803,3331,15,783,
.dw 2099,3331,4466,835,2099,3331,15,783,
.dw 2103,3331,15,783,2103,3331,15,783,
.dw 2803,3331,2813,783,2803,3331,15,783,
.dw 2227,3331,2813,783,2227,3331,15,783,
.dw 2231,3331,4466,835,2231,3331,15,783,
.dw 1875,3331,15,783,1875,3331,15,783,
.dw 2099,3331,2813,783,2099,3331,15,783,
.dw 2227,3331,2813,783,2227,3331,15,783,
.dw 2803,3331,4466,835,2803,3331,15,783,
.dw 2807,3331,15,783,2807,3331,15,783,
.dw 1667,3331,2813,783,1667,3331,15,783,
.dw 1671,3331,2813,783,1671,3331,15,783,
.dw 2803,3331,4466,835,2803,3331,15,783,
.dw 2227,3331,15,783,2227,3331,15,783,
.dw 2231,3331,2813,783,2231,3331,15,783,
.dw 2803,3331,2813,783,2803,3331,15,783,
.dw 2099,3331,4466,835,2099,3331,15,783,
.dw 2103,3331,15,783,2103,3331,15,783,
.dw 2803,3331,2813,783,2803,3331,15,783,
.dw 2227,3331,2813,835,2227,3331,15,783,
.dw 2231,3331,1985,835,2231,3331,15,783,
.dw 1875,3331,15,835,1875,3331,15,783,
.dw 2099,1667,1985,835,2099,1667,15,783,
.dw 2227,1667,1985,835,2227,1667,15,783,

.org $10000
.end
