;=============================================================================
; Original MOD file: "monkey.MOD"
; Original MOD name: "monkey island       "
; ASM file created by Mod2PSG V1.6 by Martin Konrad (mkon@gmx.de)
;=============================================================================



;=============================================================================
; Constants
;=============================================================================
RAM_START    = $C000
CONTROL_PORT = $DC
GAME_GEAR_STEREO_SOUND_PORT = $06

;=============================================================================
; PSGMOD variables
;=============================================================================
PSGMOD_PATTERN_ADDRESS  = RAM_START     ;(word)
PSGMOD_SONG_START       = RAM_START + 2 ;(word)
PSGMOD_SONG_POSITION    = RAM_START + 4 ;(byte)
PSGMOD_PATTERN_POSITION = RAM_START + 5 ;(byte)
PSGMOD_CURRENT_SPEED    = RAM_START + 6 ;(byte)
PSGMOD_SPEED_COUNTER    = RAM_START + 7 ;(byte)
PSGMOD_SOUND_DISABLED   = RAM_START + 8 ;(byte)

;=============================================================================
; Misc variables
;=============================================================================
VBLANK_COUNTER          = RAM_START + 9  ;(byte)
PREVIOUS_CONTROL_STATUS = RAM_START + 10 ;(byte)



;=============================================================================
; Start code
;=============================================================================
.org $0000
  di
  im 1
  ld sp, $dff0
  jr START

;=============================================================================
; IRQ handler
;=============================================================================
.org $0038
  exx
  ex af, af'
  in a, ($BF)

  ld hl, VBLANK_COUNTER
  inc (HL)

  exx
  ex af, af'
  ei
  reti

;=============================================================================
; NMI handler
;=============================================================================
.org $0066
  retn



START:
  call SETUP_FRAMES
  call SET_VDP_REGS_TABLE

; Set Game Gear stereo sound mask
  ld a, 195
  out (GAME_GEAR_STEREO_SOUND_PORT), a

;=============================================================================
; Song start
;=============================================================================
    ld hl, PSGMOD_SONG
  call PSGMOD_INITIATE_NEW_SONG
  ei
SONG_LOOP:
    ld d, 1                       ; wait one VBlank
  call VWAIT

  call PSGMOD_PLAY_NEXT_NOTE      ; play next note

  in a, (CONTROL_PORT)            ; get control status
  ld b, a                         ; save it to b
  ld a, (PREVIOUS_CONTROL_STATUS) ; button already pressed before?
  bit 4, a
  jr Z, BUTTON_NOT_PRESSED_AGAIN  ; jump away if yes
  ld a, b                         ; button now pressed?
  bit 4, a
  jr NZ, BUTTON_NOT_PRESSED_AGAIN ; jump away if not
  call PSGMOD_TOGGLE_SOUND        ; toggle sound on or off
BUTTON_NOT_PRESSED_AGAIN:
  ld a, b                         ; get control status from b
  ld (PREVIOUS_CONTROL_STATUS), a ; save control status to previous
                                  ; control status

  jr SONG_LOOP
;=============================================================================
; Program end
;=============================================================================

.include PSGMOD.INC



VWAIT:
  ld a, 0
  ld (VBLANK_COUNTER), a
VWAIT_LOOP:
  ld a, (VBLANK_COUNTER)
  cp d
  ret Z
  jr VWAIT_LOOP

SETUP_FRAMES:
  ld a, 0
  ld ($FFFC), a
  ld ($FFFD), a
  ld a, 1
  ld ($FFFE), a
  ld a, 2
  ld ($FFFF), a
  ret

SET_VDP_REGS_TABLE:
  ld hl, VDP_REGS_TABLE
  ld b, $0f
  ld c, $80
VDP_REGS_LOOP:
  ld a, (HL)
  inc hl
  out ($bf), a
  ld a, c
  inc c
  out ($bf), a
  dec b
  jr NZ, VDP_REGS_LOOP
  ret

VDP_REGS_TABLE:
   .db $06, $60, $FF, $FF, $FF, $FF, $00, $00, $00, $00, $FF, $00, $00, $00, $00, $00

PSGMOD_SONG:
.db 0,1,2,3,4,5,6,7
.db 8,9,10,11,12,13,14,5
.db 15,16,17,18,19,20,21,22
.db 23,18,19,20,21,22,23,24
.db 25,26,27,28,29,26,27,28
.db 29,30,128,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0

; Pattern 0:
.dw 3971,7492,15,1807,3971,7492,15,1807,
.dw 3971,7492,15,1807,3971,7492,15,1807,
.dw 3971,7492,15,1807,3971,7492,15,1807,
.dw 3971,7492,15,1807,3971,7492,15,1807,
.dw 3971,7492,15,1807,3971,7492,15,1807,
.dw 3971,7492,15,1807,3971,7492,15,1807,
.dw 3971,7492,15,1807,3971,7492,15,1807,
.dw 3971,7492,15,1807,3971,7492,15,1807,
.dw 3971,7492,15,1807,3971,7492,15,1807,
.dw 3971,7492,15,1807,3971,7492,15,1807,
.dw 3971,7492,15,1807,3971,7492,15,1807,
.dw 3971,7492,15,1807,3971,7492,15,1807,
.dw 3971,7492,15,1807,3971,7492,15,1807,
.dw 3971,7492,15,1807,3971,7492,15,1807,
.dw 3971,7492,15,1807,3971,7492,15,1807,
.dw 3971,7492,15,1807,3971,7492,15,1807,
.dw 3971,7492,1873,1551,3971,7492,2497,1551,
.dw 3971,7492,3137,1551,3971,7492,3328,1807,
.dw 3971,7492,3328,1807,3971,7492,3328,1807,
.dw 3971,7492,3328,2319,3971,7492,3329,2319,
.dw 3971,7492,4208,1551,3971,7492,4208,1551,
.dw 3971,7492,4208,1807,3971,7492,4209,1807,
.dw 3971,7492,3744,1551,3971,7492,3744,1551,
.dw 3971,7492,3744,1295,3971,7492,3745,1295,
.dw 3971,7492,3328,1551,3971,7492,3328,1551,
.dw 3971,7492,3328,1551,3971,7492,3329,1551,
.dw 3971,7492,4208,1551,3971,7492,4208,1551,
.dw 3971,7492,4208,1295,3971,7492,4209,1295,
.dw 3971,7492,3744,1551,3971,7492,3744,1551,
.dw 3971,7492,3744,1807,3971,7492,3745,1807,
.dw 3971,7492,4992,5391,3971,7492,4992,5391,
.dw 3971,7492,4992,5391,3971,7492,3140,5391,
; Pattern 1:
.dw 15,6292,2804,2831,15,6292,2804,2831,
.dw 15,6292,2498,2630,15,6292,2498,2575,
.dw 15,6292,2496,2635,15,6292,2496,1606,
.dw 15,6292,2498,1551,15,6292,2500,2580,
.dw 15,6292,2511,2575,15,6292,2511,3140,
.dw 15,6292,2511,3087,15,6292,2511,2630,
.dw 15,6292,2511,2575,15,6292,2511,2630,
.dw 15,6292,2511,1604,15,6293,2511,1551,
.dw 15,5604,8420,2628,15,5604,8420,2575,
.dw 15,5604,8420,2630,15,5604,8420,2575,
.dw 15,5604,8420,2635,15,5604,8932,2575,
.dw 15,5604,8932,2575,15,5604,8932,2575,
.dw 15,5604,8932,2575,15,5604,8932,2575,
.dw 15,5604,8932,2575,15,5604,8932,2575,
.dw 15,5604,8932,2575,15,5604,8932,2575,
.dw 15,5604,8932,2575,15,5605,8932,2575,
.dw 15,6292,8932,2631,15,6292,8932,2575,
.dw 15,6292,8420,2575,15,6292,8420,2575,
.dw 15,6292,8420,2575,15,6292,8420,2575,
.dw 15,6292,8420,2575,15,6292,8420,2575,
.dw 15,6292,8420,2575,15,6292,7492,2575,
.dw 15,6292,7492,2575,15,6292,7492,2575,
.dw 15,6292,7492,2575,15,6293,7492,2575,
.dw 15,6676,6676,2631,15,6676,6676,2575,
.dw 15,6676,6292,2575,15,6676,6292,2575,
.dw 15,6676,6292,2575,15,6676,6292,2575,
.dw 15,6676,5604,2575,15,6676,5604,2575,
.dw 15,8418,5604,2631,15,8418,5604,2575,
.dw 15,8418,4996,2575,15,8418,4996,2575,
.dw 15,8418,4996,2575,15,8418,4996,2575,
.dw 15,8418,4212,2575,15,8418,4212,2575,
.dw 15,8418,4212,2575,15,8418,4212,2575,
; Pattern 2:
.dw 4721,1875,15,1089,15,1876,15,1039,
.dw 1885,3747,15,1103,15,3748,15,1039,
.dw 1872,3139,15,1089,15,3140,15,1103,
.dw 1872,3747,15,1089,15,3748,15,1055,
.dw 15,2499,15,1039,15,2500,15,1103,
.dw 1879,3139,15,1039,15,3140,15,1103,
.dw 1872,3747,15,1039,15,3748,15,1103,
.dw 1872,6291,15,1103,15,6292,15,1039,
.dw 15,8419,15,1103,15,8420,15,1039,
.dw 1879,4211,15,1103,15,4212,15,1039,
.dw 2096,3331,15,1090,15,3332,15,1039,
.dw 2096,5603,15,1090,15,5604,15,1039,
.dw 4721,7491,15,1090,15,7492,15,1039,
.dw 2103,3747,15,1039,1885,3748,15,1039,
.dw 1872,3139,15,1090,15,3140,15,1039,
.dw 1872,3747,15,1090,15,3748,15,1039,
.dw 15,2499,15,1103,15,2500,15,1039,
.dw 1879,3139,15,1039,15,3140,15,1039,
.dw 1872,3747,15,1039,15,3748,15,1039,
.dw 1872,6291,15,1039,15,6292,15,1039,
.dw 15,8419,15,1090,15,8420,15,1039,
.dw 1879,4211,15,1039,15,4212,15,1039,
.dw 2096,3331,15,1090,15,3332,15,1039,
.dw 2096,4211,15,1090,15,4211,15,-31729,
.dw 15,4217,15,1039,15,4217,15,1039,
.dw 15,4217,15,1039,15,4217,15,1039,
.dw 15,4217,15,1039,15,4217,15,1039,
.dw 15,4217,15,1103,15,4217,15,1039,
.dw 15,4217,15,1039,15,4217,15,1039,
.dw 15,4217,15,1039,15,4217,15,1039,
.dw 15,4217,15,1039,15,4217,15,1039,
.dw 15,4217,15,1039,15,4217,15,1039,
; Pattern 3:
.dw 15,7491,15,1089,15,7492,15,1039,
.dw 2103,3747,15,1089,15,3748,15,1039,
.dw 1872,3139,15,1103,15,3140,15,1103,
.dw 1872,3747,15,1103,15,3748,15,1071,
.dw 15,4995,3744,1039,15,4996,3744,1103,
.dw 1879,3139,3748,1039,15,3140,3748,1103,
.dw 1872,3747,3744,1039,15,3748,3745,1103,
.dw 1872,6291,3136,1103,15,6292,3137,1039,
.dw 15,8419,3328,1103,15,8420,3332,1039,
.dw 1879,4211,3744,1103,15,4212,3745,1039,
.dw 2096,3331,4208,1090,15,3332,4208,1039,
.dw 2096,5603,4212,1090,15,5604,4212,1039,
.dw 15,9459,3744,1089,15,9460,3744,1039,
.dw 2103,3747,3744,1039,15,3748,3744,1039,
.dw 2352,3139,3744,1089,15,3140,3744,1039,
.dw 2352,2355,3744,1089,15,2355,3744,1039,
.dw 2498,2361,3746,1089,2509,2367,3748,1039,
.dw 2509,2355,3751,1039,2509,2356,3751,1039,
.dw 3138,6291,4208,1089,3149,6292,4208,1039,
.dw 3149,6291,4212,1089,3149,6291,4212,1039,
.dw 3138,6297,4208,1103,3149,6303,4209,1039,
.dw 3149,6291,4720,1039,3149,6292,4724,1039,
.dw 3138,6291,4992,1103,3149,6292,4993,1039,
.dw 2498,6291,4208,1103,2509,6291,4209,1039,
.dw 2802,6297,4720,1039,2813,6303,4720,1039,
.dw 2813,6303,4724,1039,2813,6303,4724,1039,
.dw 2802,5603,4720,1090,2813,5604,4720,1039,
.dw 2813,5603,4724,1090,2813,5603,4724,1039,
.dw 3138,5609,4992,1090,3149,5615,4992,1039,
.dw 3151,5615,4992,1039,3151,5615,4992,1039,
.dw 3151,6291,4992,1090,3151,6292,4992,1039,
.dw 3151,6291,4992,1090,3151,6291,4992,1039,
; Pattern 4:
.dw 15,7491,15,1089,15,7492,15,1039,
.dw 1879,3747,15,1103,15,3748,15,1039,
.dw 1872,3139,3744,1103,15,3140,3744,1103,
.dw 1872,3747,3748,1103,15,3748,3748,1071,
.dw 15,4995,3744,1039,15,4996,3744,1103,
.dw 1879,3139,3744,1039,15,3140,3745,1103,
.dw 1872,3747,3744,1039,15,3748,3745,1103,
.dw 1872,6291,3136,1103,15,6292,3137,1039,
.dw 15,8419,3328,1089,15,8420,3332,1039,
.dw 1879,4211,3744,1103,15,4212,3745,1039,
.dw 2096,3331,4208,1089,15,3332,4208,1039,
.dw 2096,5603,4212,1089,15,5604,4212,1039,
.dw 15,9459,3744,1089,15,9460,3744,1039,
.dw 2103,3747,3744,1039,15,3748,3744,1039,
.dw 2352,3139,3744,1089,15,3140,3744,1039,
.dw 2352,2355,3744,1089,15,2355,3744,1039,
.dw 2498,2361,3744,1103,2509,2367,3744,1039,
.dw 2509,2355,3746,1039,2509,2356,3748,1039,
.dw 3138,6291,3751,1103,3149,6292,3751,1039,
.dw 3149,6291,3328,1103,3149,6291,3329,1039,
.dw 3138,6297,3136,1089,3149,6303,3136,1039,
.dw 3149,6291,3140,1089,3149,6292,3140,1039,
.dw 3149,4995,3136,1103,3149,4996,3136,1039,
.dw 2498,4995,3136,1089,2509,4995,3137,1039,
.dw 2802,5001,2800,1089,2813,5007,2800,1039,
.dw 2813,5007,2800,1039,2813,5007,2800,1039,
.dw 2802,5603,2800,1089,2813,5604,2800,1039,
.dw 2813,5603,2800,1089,2813,5603,2801,1039,
.dw 4210,5609,3328,1089,4221,5615,3328,1039,
.dw 4223,2096,3328,1089,4223,2804,3328,1039,
.dw 2096,2096,3328,1103,15,2804,3329,1039,
.dw 2096,2096,3136,1103,15,2804,3136,1039,
; Pattern 5:
.dw 15,15,3328,1103,15,15,3332,1039,
.dw 15,15,3744,1103,15,15,3748,1039,
.dw 2096,2096,4208,1103,15,2100,4209,1103,
.dw 2096,2111,3328,1103,15,2111,3328,-31697,
.dw 15,2111,3328,1039,15,2111,3328,1103,
.dw 15,2111,3328,1039,15,2111,3328,1103,
.dw 15,2111,3328,1039,15,2111,3328,1103,
.dw 15,2111,3328,1103,15,2111,3328,1039,
.dw 15,2111,3328,1103,15,2111,3328,1039,
.dw 15,2111,3328,1103,15,2111,3328,1039,
.dw 15,2111,3328,1103,15,2111,3328,1039,
.dw 15,2111,3328,1103,15,2111,3328,1039,
.dw 15,2111,3328,1103,15,2111,3328,1039,
.dw 15,2111,3328,1039,15,2111,3328,1039,
.dw 15,2111,3328,1103,15,2111,3328,1039,
.dw 15,2111,3328,1103,15,2111,3329,1039,
.dw 2096,2111,4208,1103,15,2111,4209,1039,
.dw 2096,2111,3328,1039,15,2111,3328,-31729,
.dw 15,2111,3328,1103,15,2111,3328,1039,
.dw 15,2111,3328,1103,15,2111,3328,1039,
.dw 15,2111,3328,1103,15,2111,3328,1039,
.dw 15,2111,3328,1103,15,2111,3328,1039,
.dw 15,2111,3328,1103,15,2111,3328,1039,
.dw 15,2111,3328,1103,15,2111,3328,1039,
.dw 15,2111,3328,1103,15,2111,3328,1039,
.dw 15,2111,3328,1039,15,2111,3328,1039,
.dw 15,2111,3328,1103,15,2111,3328,1039,
.dw 15,2111,3328,1103,15,2111,3328,1039,
.dw 15,2111,3328,1103,15,2111,3328,1039,
.dw 15,2111,3328,1103,15,2111,3328,1039,
.dw 15,2111,3328,1103,15,2111,3328,1039,
.dw 15,2111,3328,1103,15,2111,3328,1039,
; Pattern 6:
.dw 15,2500,3136,1089,15,2502,3136,1039,
.dw 15,2500,3140,1089,15,2502,3140,1039,
.dw 1568,2500,3136,1103,15,2503,3136,1103,
.dw 1568,2502,3136,1089,15,15,3137,1071,
.dw 15,1988,3328,1089,15,1990,3328,1103,
.dw 1575,1988,3328,1039,15,1988,3329,1103,
.dw 2496,2500,3328,1089,15,2502,3328,1103,
.dw 2496,1988,3332,1089,15,1990,3332,1039,
.dw 15,1876,3744,1089,15,1878,3744,1039,
.dw 2503,1876,3744,1089,15,1878,3744,1039,
.dw 1872,1876,3744,1103,15,1878,3745,1039,
.dw 1872,1876,3136,1103,15,1876,3137,1039,
.dw 15,2100,3328,1103,15,2102,3332,1039,
.dw 1879,2100,3744,1039,15,2102,3745,1039,
.dw 2096,2100,4208,1103,15,2102,4209,1039,
.dw 2096,15,3328,1103,15,15,3329,1039,
.dw 15,15,3136,1089,15,15,3136,1039,
.dw 2103,15,3140,1089,15,15,3140,1039,
.dw 1568,2500,3136,1103,15,2500,3136,1039,
.dw 1568,2500,3136,1089,15,2500,3137,1039,
.dw 15,2500,3328,1089,15,2502,3328,1039,
.dw 1575,2500,3328,1103,15,2502,3329,1039,
.dw 2496,2356,3328,1089,15,2358,3328,1039,
.dw 2496,1988,3332,1089,15,1990,3332,1039,
.dw 15,1876,3744,1089,15,1878,3744,1039,
.dw 2503,1876,3744,1089,15,1878,3744,1039,
.dw 1872,1876,3744,1103,15,1878,3745,1039,
.dw 1872,15,3136,1103,15,15,3137,1039,
.dw 15,2100,3328,1103,15,2102,3329,1039,
.dw 1879,2100,3744,1103,15,2102,3748,1039,
.dw 2096,2100,4208,1103,15,2102,4208,1039,
.dw 2096,15,4208,1103,15,15,4208,1039,
; Pattern 7:
.dw 15,2356,3744,1089,15,2358,3744,1039,
.dw 15,2356,3748,1089,15,2358,3748,1039,
.dw 2352,2356,3744,1103,15,2356,3744,1103,
.dw 2352,2356,3744,1089,15,2356,3745,1071,
.dw 15,2356,3744,1089,15,2358,3744,1103,
.dw 2359,2356,3744,1039,15,2358,3744,1103,
.dw 2352,2356,3744,1103,15,2356,3744,1103,
.dw 2352,2356,3744,1103,15,2356,3744,1039,
.dw 2498,2356,3744,1103,2509,2356,3746,1039,
.dw 2511,2356,3748,1103,2511,2356,3751,1039,
.dw 3138,6292,3744,1103,3149,6292,3744,1039,
.dw 3151,6292,3744,1103,3151,6292,3745,1039,
.dw 3138,6295,4208,1089,3149,6295,4209,1039,
.dw 3151,6303,4720,1089,3151,6303,4724,1039,
.dw 3151,4996,4992,1103,3151,4996,4993,1039,
.dw 2498,4996,4208,1089,2509,4996,4209,1039,
.dw 2802,4999,4720,1089,2813,4999,4720,1039,
.dw 2815,5007,4724,1103,2815,5007,4724,1039,
.dw 2802,5604,4720,1089,2813,5604,4720,1039,
.dw 2815,5604,4720,1089,2815,5604,4721,-31729,
.dw 2498,5615,4992,1089,2509,5615,4992,1039,
.dw 2511,5615,4992,1103,2511,5615,4992,1039,
.dw 2511,5615,4992,1103,2511,5615,4992,1039,
.dw 2511,5615,4994,1103,2511,5615,4996,1039,
.dw 2511,5615,4999,1103,2511,5615,4999,-31729,
.dw 2511,5615,4999,1103,2511,5615,4999,1039,
.dw 2511,5615,4999,1103,2511,5615,4999,1039,
.dw 2511,5615,4999,1103,2511,5615,4999,1039,
.dw 2511,5615,4999,1103,2511,5615,4999,1039,
.dw 2511,5615,4999,1103,2511,5615,4999,1039,
.dw 2511,5615,4999,1103,2511,5615,4999,1039,
.dw 2511,5615,4999,1103,2511,5615,4999,1039,
; Pattern 8:
.dw 2498,7491,4992,1089,2509,7492,4992,1039,
.dw 2511,3747,4992,1103,2511,3748,4992,1039,
.dw 1872,3139,4994,1089,15,3140,4996,1103,
.dw 1872,3747,4999,1089,15,3748,5005,1071,
.dw 15,2499,5005,1103,15,2500,5005,1103,
.dw 15,3139,5005,1039,15,3140,5005,1103,
.dw 1872,3747,5005,1103,15,3748,5005,1103,
.dw 1872,6291,5005,1103,15,6292,5005,1039,
.dw 15,8419,5005,1103,15,8420,5005,1039,
.dw 15,4211,5005,1103,15,4212,5005,1039,
.dw 2096,3331,5005,1090,15,3332,5005,1039,
.dw 2096,5603,5005,1090,15,5604,5005,1039,
.dw 15,7491,5005,1090,15,7492,5005,1039,
.dw 15,3747,5005,1103,15,3748,5005,1039,
.dw 1872,3139,5005,1090,15,3140,5005,1039,
.dw 1872,3747,5005,1090,15,3748,5005,1039,
.dw 15,4995,5005,1103,15,4996,5005,1039,
.dw 15,3139,5005,1103,15,3140,5005,1039,
.dw 1872,3747,5005,1103,15,3748,5005,1039,
.dw 1872,6291,5005,1103,15,6292,5005,1039,
.dw 15,8419,4992,1090,15,8420,4992,1039,
.dw 15,4211,4992,1103,15,4212,4993,1039,
.dw 2096,3331,4208,1090,15,3332,4208,1039,
.dw 2096,4211,4212,1090,15,4211,4212,-31729,
.dw 15,4217,4212,1103,15,4217,4212,1039,
.dw 15,4217,4212,1103,15,4217,4212,1039,
.dw 15,4217,4212,1103,15,4217,4212,1039,
.dw 15,4217,4212,1103,15,4217,4212,1039,
.dw 15,4217,4212,1103,15,4217,4212,1039,
.dw 15,4217,4212,1103,15,4217,4212,1039,
.dw 15,4217,4212,1103,15,4217,4212,1039,
.dw 15,4217,4212,1103,15,4217,4212,1039,
; Pattern 9:
.dw 2498,15,3744,1089,2509,15,3744,1039,
.dw 4722,15,3744,1103,4733,15,3745,1039,
.dw 3138,3140,3136,1089,3149,3140,3136,1103,
.dw 4722,3140,3140,1089,4733,3140,3140,1071,
.dw 3138,3143,3136,1103,3149,3143,3136,1103,
.dw 4994,3143,3136,1039,5005,3143,3136,1103,
.dw 3746,3140,3136,1103,3757,3140,3136,1103,
.dw 4994,3140,3136,1103,5005,3140,3137,1039,
.dw 3746,3143,4720,1103,3757,3143,4721,1039,
.dw 4994,3143,2496,1103,5005,3143,2500,1039,
.dw 4210,3140,2800,1103,4221,3140,2804,1039,
.dw 4994,3140,2352,1103,5005,3140,2353,1039,
.dw 2498,3143,4208,1103,2509,3143,4208,1039,
.dw 4994,3143,4208,1103,5005,3143,4209,1039,
.dw 4210,4212,3136,1089,4221,4212,3136,1039,
.dw 4994,4212,3140,1089,5005,4212,3140,1039,
.dw 3138,4215,3136,1089,3149,4215,3136,1039,
.dw 4994,4215,3136,1103,5005,4215,3136,1039,
.dw 4210,4212,3136,1089,4221,4212,3136,1039,
.dw 4994,4212,3136,1103,5005,4212,3137,1039,
.dw 3138,4215,4992,1103,3149,4215,4992,1039,
.dw 4994,4215,4992,1103,5005,4215,4993,1039,
.dw 4210,4212,3136,1103,4221,4212,3136,1039,
.dw 4994,4212,3136,1103,5005,4212,3136,-31729,
.dw 3138,4215,3136,1103,3149,4215,3136,1039,
.dw 4994,4223,3136,1103,5005,4223,3136,1039,
.dw 3746,4223,3136,1103,3757,4223,3136,1039,
.dw 4994,4223,3136,1103,5005,4223,3136,1039,
.dw 2498,4223,3136,1103,2509,4223,3136,1039,
.dw 4994,4223,3136,1103,5005,4223,3136,1039,
.dw 3138,4223,3136,1103,3149,4223,3136,1039,
.dw 4994,4223,3136,1103,5005,4223,3136,1039,
; Pattern 10:
.dw 3138,15,4720,1089,3149,15,4720,1039,
.dw 4994,15,4720,1103,5005,15,4721,1039,
.dw 3746,2356,4208,1089,3757,2356,4208,1103,
.dw 4994,2356,4212,1089,5005,2356,4212,1071,
.dw 2498,2356,4208,1089,2509,2356,4208,1103,
.dw 4994,2356,4208,1039,5005,2356,4208,1103,
.dw 3138,2356,4208,1089,3149,2356,4209,1103,
.dw 3746,2356,2800,1103,3757,2356,2801,1039,
.dw 3138,2356,4208,1089,3149,2356,4209,1039,
.dw 3330,2356,2800,1103,3341,2356,2804,1039,
.dw 3746,2356,3136,1103,3757,2356,3143,1039,
.dw 3330,2356,2800,1103,3341,2356,2807,1039,
.dw 3138,2356,3136,1089,3149,2356,3143,1039,
.dw 4994,2356,3143,1089,5005,2356,3143,1039,
.dw 3746,3748,3328,1089,3757,3748,3335,1039,
.dw 4994,3748,3335,1103,5005,3748,3335,1039,
.dw 3746,3748,3744,1089,3757,3748,3744,1039,
.dw 4994,3748,3744,1103,5005,3748,3745,1039,
.dw 3746,3748,4992,1089,3757,3748,4992,1039,
.dw 4994,3748,4999,1103,5005,3748,4999,1039,
.dw 3746,3748,4992,1089,3757,3748,4992,1039,
.dw 4994,3748,4992,1103,5005,3748,4992,1039,
.dw 3746,3748,4992,1103,3757,3748,4992,1039,
.dw 4994,3748,4992,1103,5005,3748,4993,1039,
.dw 3746,3748,6672,1103,3757,3748,6672,1039,
.dw 4994,3748,6672,1103,5005,3748,6673,1039,
.dw 3746,3748,6288,1089,3757,3748,6288,1039,
.dw 4994,3748,6292,1089,5005,3748,6292,-31729,
.dw 5005,3748,6292,1103,5005,3748,6292,1039,
.dw 5005,3748,6292,1103,5005,3748,6292,1039,
.dw 5005,3748,6292,1103,5005,3748,6292,1039,
.dw 5005,3748,6292,1103,5005,3748,6292,1039,
; Pattern 11:
.dw 3536,15,2811,1089,15,15,2811,1039,
.dw 15,3540,2811,1103,15,3540,2811,1039,
.dw 1760,1764,2811,1089,15,1764,2811,1103,
.dw 1760,2356,2811,1103,15,2356,2811,1071,
.dw 15,2356,2811,1089,15,2356,2811,1103,
.dw 15,2804,2811,1039,15,2804,2811,1103,
.dw 15,1764,2811,1103,15,1764,2811,1103,
.dw 15,1396,2811,1103,15,1396,2811,1039,
.dw 15,3540,2811,1103,15,3540,2811,1039,
.dw 15,2804,2811,1103,15,2804,2811,1039,
.dw 1760,1764,2811,1103,15,1764,2811,1039,
.dw 1760,3540,2811,1103,15,3540,2811,1039,
.dw 15,2356,2811,1103,15,2356,2811,1039,
.dw 15,2356,2811,1103,15,2356,2811,1039,
.dw 15,1396,2811,1089,15,1396,2811,1039,
.dw 15,1764,2811,1089,15,1764,2813,1039,
.dw 1250,1771,3147,1089,1261,1775,3147,1039,
.dw 1263,1775,3147,1103,1263,1775,3147,1039,
.dw 1570,3140,3147,1089,1581,3140,3147,1039,
.dw 1583,3140,3147,1103,1583,3140,3147,1039,
.dw 1570,3140,3147,1089,1581,3140,3147,1039,
.dw 1583,3140,3147,1103,1583,3140,3147,1039,
.dw 1583,3140,3147,1103,1583,3140,3147,1039,
.dw 1570,3140,3147,1103,1581,3140,3147,1039,
.dw 1666,3140,3147,1103,1677,3140,3147,1039,
.dw 1679,3140,3147,1103,1679,3140,3147,1039,
.dw 1570,3140,3147,1103,1581,3140,3147,1039,
.dw 1583,3140,3147,1103,1583,3140,3147,1039,
.dw 1666,3140,3147,1090,1677,3140,3147,1090,
.dw 1570,3140,3147,1089,1581,3140,3147,1039,
.dw 1874,3140,3757,1089,1885,3140,3757,1039,
.dw 1570,3140,3757,1089,1581,3140,3757,1039,
; Pattern 12:
.dw 15,15,3147,1089,15,15,3147,1039,
.dw 15,4724,3147,1103,15,4724,3147,1039,
.dw 2352,2356,3147,1089,15,2356,3147,1103,
.dw 2352,3140,3147,1103,15,3140,3147,1071,
.dw 15,1572,3147,1089,15,1572,3147,1103,
.dw 15,3972,3147,1039,15,3972,3147,1103,
.dw 2352,2100,3147,1103,15,2100,3147,1103,
.dw 2352,1988,3147,1103,15,1988,3149,1039,
.dw 15,4724,2363,1103,15,4724,2363,1039,
.dw 15,3140,2363,1103,15,3140,2363,1039,
.dw 2352,2356,2363,1103,15,2356,2363,1039,
.dw 2352,3972,2363,1103,15,3972,2363,1039,
.dw 15,1572,2363,1103,15,1572,2363,1039,
.dw 15,3140,2363,1103,15,3140,2363,1039,
.dw 2352,1988,2363,1089,15,1988,2363,1039,
.dw 15,2356,2363,1089,15,2356,2365,1039,
.dw 1394,2363,2107,1089,1405,2367,2107,1039,
.dw 1407,2367,2107,1103,1407,2367,2107,1039,
.dw 1666,4212,2107,1089,1677,4212,2107,1039,
.dw 1679,4212,2107,1103,1679,4212,2107,1039,
.dw 1666,4219,2107,1089,1677,4223,2107,1039,
.dw 1679,4223,2107,1103,1679,4223,2107,1039,
.dw 1679,4212,2107,1103,1679,4212,2107,1039,
.dw 1666,4212,2107,1103,1677,4212,2107,1039,
.dw 1874,4219,2107,1103,1885,4223,2107,1039,
.dw 1887,4223,2107,1103,1887,4223,2107,1039,
.dw 1666,4212,2107,1103,1677,4212,2107,1039,
.dw 1679,4212,2107,1103,1679,4212,2107,1039,
.dw 1874,4219,2107,1103,1885,4223,2109,1103,
.dw 1666,4223,2111,1103,1677,4223,2111,1039,
.dw 2098,4212,2111,1089,2109,4212,2111,1039,
.dw 2111,4212,2111,1089,2111,4212,2111,1039,
; Pattern 13:
.dw 1874,4724,3744,1089,1885,15,3744,1039,
.dw 1887,15,3748,1103,1887,15,3748,1039,
.dw 1872,6292,3744,1089,15,6292,3745,1103,
.dw 1872,3140,3136,1089,15,3140,3137,1071,
.dw 15,4212,3328,1103,15,4212,3332,1103,
.dw 15,5604,3744,1039,15,5604,3745,1103,
.dw 2096,6676,4208,1089,15,6676,4208,1103,
.dw 2096,3332,4208,1089,15,3332,4209,1039,
.dw 15,3140,3744,1089,15,3140,3744,1039,
.dw 15,6292,3744,1089,15,6292,3744,1039,
.dw 2352,3140,3744,1103,15,3140,3744,1039,
.dw 2352,3147,3744,1089,15,3151,3744,1039,
.dw 2498,3151,3746,1089,2509,3151,3747,1039,
.dw 4210,3151,3751,1103,4221,3151,3751,1039,
.dw 3138,3140,4208,1089,3149,3140,4208,1039,
.dw 4210,3140,4212,1089,4221,3140,4212,1039,
.dw 3138,3147,4208,1103,3149,3151,4209,1039,
.dw 4210,3151,4720,1103,4221,3151,4721,1039,
.dw 3138,3140,4992,1103,3149,3140,4994,1039,
.dw 2498,3140,4208,1103,2509,3140,4212,1039,
.dw 2802,3143,4720,1089,2813,3143,4720,1039,
.dw 4722,3143,4724,1089,4733,3143,4724,1039,
.dw 2802,2804,4720,1103,2813,2804,4720,1039,
.dw 4722,2804,4724,1089,4733,2804,4724,1039,
.dw 3138,2807,4992,1089,3149,2807,4992,1039,
.dw 4994,2807,4992,1103,5005,2807,4992,1039,
.dw 3746,3140,4992,1089,3757,3140,4992,1039,
.dw 4994,3140,4992,1089,5005,3140,4992,1039,
.dw 5005,3143,4994,1103,5005,3143,4996,1103,
.dw 5005,3143,4999,1103,5005,3143,4999,-31729,
.dw 5005,3143,4999,1103,5005,3143,4999,1039,
.dw 5005,3143,4999,1103,5005,3143,4999,1039,
; Pattern 14:
.dw 1872,6292,3744,1103,15,6292,3744,1039,
.dw 1872,3140,3748,1103,15,3140,3748,1039,
.dw 15,3748,3744,1103,15,3748,3744,1103,
.dw 1879,4996,3744,1103,15,4996,3744,1071,
.dw 1872,3748,3744,1089,15,3748,3745,1103,
.dw 1872,3748,3136,1089,15,3748,3137,1103,
.dw 15,4212,3328,1089,15,4212,3332,1103,
.dw 1879,2804,3744,1089,15,2804,3745,1039,
.dw 2096,3748,4208,1103,15,3748,4208,1039,
.dw 2096,2500,4208,1089,15,2500,4209,1039,
.dw 15,2356,3744,1089,15,2356,3744,1039,
.dw 2103,3140,3744,1103,15,3140,3744,1039,
.dw 2352,3748,3744,1089,15,3748,3744,1039,
.dw 2352,3751,3744,1089,15,3751,3744,1039,
.dw 2354,3759,3744,1103,2365,3759,3744,1039,
.dw 3138,3759,3744,1103,3149,3759,3746,1039,
.dw 2354,4724,3748,1103,2365,4724,3751,1039,
.dw 2098,4724,3328,1103,2109,4724,3329,1039,
.dw 2498,4727,3136,1089,2509,4727,3136,1039,
.dw 3138,4727,3140,1089,3149,4727,3140,1039,
.dw 2498,4996,3136,1103,2509,4996,3136,1039,
.dw 3138,4996,3136,1089,3149,4996,3137,1039,
.dw 2354,4999,2800,1089,2365,4999,2800,1039,
.dw 2802,4999,2800,1103,2813,4999,2800,1039,
.dw 2354,4724,2800,1089,2365,4724,2800,1039,
.dw 2802,4724,2800,1089,2813,4724,2801,1039,
.dw 2098,2804,3328,1089,2109,2809,3328,1039,
.dw 3330,2804,3328,1089,3341,2809,3328,1039,
.dw 2802,2804,3328,1103,2813,2809,3329,1103,
.dw 2813,2804,3136,1103,2813,2809,3137,1039,
.dw 2813,2804,3328,1103,2813,2804,3332,1039,
.dw 2813,2804,3744,1103,2813,2804,3744,-31729,
; Pattern 15:
.dw 15,2500,3136,1089,15,2502,3136,1039,
.dw 15,2500,3136,1089,15,2502,3137,1039,
.dw 1568,2500,3136,1103,15,2503,3136,1103,
.dw 1568,2502,3136,1089,15,15,3137,1071,
.dw 15,1988,3328,1089,15,1990,3328,1103,
.dw 15,1988,3328,1103,15,1990,3328,1103,
.dw 2496,1988,3328,1089,15,1991,3328,1103,
.dw 2496,1990,3328,1089,15,15,3329,1039,
.dw 15,1876,3744,1089,15,1878,3744,1039,
.dw 15,1876,3744,1089,15,1878,3744,1039,
.dw 1872,1876,3744,1103,15,1878,3745,1039,
.dw 1872,1876,3136,1103,15,1876,3137,1039,
.dw 15,1876,3328,1103,15,1876,3332,1039,
.dw 15,1876,3744,1103,15,1876,3745,1039,
.dw 2096,2100,4208,1103,15,2102,4209,1039,
.dw 2096,2100,3328,1103,15,2102,3335,1039,
.dw 15,2500,3136,1089,15,2502,3136,1039,
.dw 15,2500,3140,1089,15,2502,3140,1039,
.dw 1568,2500,3136,1103,15,2503,3136,1039,
.dw 1568,2502,3140,1089,15,15,3140,1039,
.dw 15,1990,3328,1089,15,1988,3328,1039,
.dw 15,1990,3328,1103,15,1988,3329,1039,
.dw 1248,1991,3328,1089,15,1990,3328,1039,
.dw 1248,15,3328,1089,15,15,3329,1039,
.dw 15,1876,3744,1089,15,1878,3744,1039,
.dw 15,1876,3744,1089,15,1878,3744,1039,
.dw 1872,1876,3744,1103,15,1878,3745,1039,
.dw 1872,1876,3136,1103,15,1876,3137,1039,
.dw 15,1876,3328,1103,15,1876,3329,1103,
.dw 15,1876,3744,1103,15,1876,3748,1039,
.dw 2096,2100,4208,1103,15,2102,4208,1039,
.dw 2096,2100,4208,1103,15,2102,4208,1039,
; Pattern 16:
.dw 15,2356,3744,1089,15,2358,3744,1039,
.dw 15,2356,3748,1089,15,2358,3748,1039,
.dw 2352,2356,3744,1103,15,2358,3744,1103,
.dw 2352,2356,3748,1089,15,2358,3748,1071,
.dw 1874,1767,3744,1089,1885,15,3744,1103,
.dw 1887,15,3744,1103,1887,15,3744,1103,
.dw 2098,15,3744,1103,2109,15,3744,1103,
.dw 2354,15,3744,1103,2365,15,3744,1039,
.dw 2498,3140,3744,1089,2509,3140,3745,1039,
.dw 2511,3140,3747,1089,2511,3140,3748,1039,
.dw 3138,3140,4208,1103,3149,3140,4208,1039,
.dw 4210,3140,4212,1089,4221,3140,4212,1039,
.dw 2802,3140,4720,1089,2813,3140,4721,1039,
.dw 4210,3140,4992,1103,4221,3140,4993,1039,
.dw 2802,2804,4720,1089,2813,2804,4720,1039,
.dw 3746,2804,4724,1089,3757,2804,4724,1039,
.dw 3138,2804,4992,1089,3149,2804,4992,1039,
.dw 3151,7492,4992,1103,3151,7492,4992,1039,
.dw 1872,4212,4992,1089,15,4212,4992,1039,
.dw 1872,3748,4992,1089,15,3748,4992,1039,
.dw 15,3332,4994,1103,15,3332,4996,1039,
.dw 15,7492,4999,1103,15,7492,5005,1039,
.dw 1872,5604,3744,1103,15,5604,3744,1039,
.dw 1872,2804,3748,1103,15,2804,3748,1039,
.dw 15,2500,3744,1103,15,2502,3744,1039,
.dw 15,2500,3746,1103,15,2502,3746,1039,
.dw 1872,2500,3746,1103,15,2502,3746,1039,
.dw 1872,2500,3136,1103,15,2502,3137,1039,
.dw 15,2498,3328,1103,15,15,3329,1103,
.dw 15,2802,3744,1103,15,15,3745,1039,
.dw 2096,15,4208,1089,15,15,4208,1039,
.dw 2096,3138,4208,1089,15,15,4208,1039,
; Pattern 17:
.dw 15,3140,3744,1089,15,3142,3744,1039,
.dw 15,3140,3748,1089,15,3142,3748,1039,
.dw 2352,3140,3744,1103,15,3142,3744,1103,
.dw 2352,3140,3748,1089,15,3143,3748,1071,
.dw 3138,3142,3744,1089,3149,15,3744,1103,
.dw 3746,15,3744,1103,3757,15,3744,1103,
.dw 2498,15,3744,1103,2509,15,3745,1103,
.dw 3138,15,3136,1103,3149,15,3137,1039,
.dw 2098,15,2800,1089,2109,15,2801,1039,
.dw 2802,15,3136,1089,2813,15,3140,1039,
.dw 4210,5604,3328,1103,4221,5604,3329,1039,
.dw 3330,5604,2800,1089,3341,5604,2801,1039,
.dw 3746,5604,3136,1089,3757,5604,3137,1039,
.dw 3138,5609,3744,1103,3149,5615,3748,1039,
.dw 3330,5615,3328,1089,3341,5615,3328,1039,
.dw 3343,5615,3328,1089,3343,5615,3329,1039,
.dw 3746,5615,3744,1089,3757,5615,3744,1039,
.dw 3759,5615,3744,1103,3759,5615,3744,1039,
.dw 3759,5615,3744,1103,3759,5615,3744,1039,
.dw 3759,5615,3744,1103,3759,5615,3746,1039,
.dw 3759,5615,3749,1103,3759,5615,3757,1039,
.dw 3759,5615,3759,1103,3759,5615,3759,1039,
.dw 3759,5615,3759,1103,3759,5615,3759,1039,
.dw 3759,5615,3759,1103,3759,5615,3759,1039,
.dw 3759,5615,3759,1103,3759,5615,3759,1039,
.dw 3759,5615,3759,1103,3759,5615,3759,1039,
.dw 3759,5615,3759,1103,3759,5615,3759,1039,
.dw 3759,5615,3759,1103,3759,5615,3759,1039,
.dw 3759,5615,3759,1103,3759,5615,3759,1103,
.dw 3759,5615,3759,1103,3759,5615,3759,1039,
.dw 3759,5615,3759,1103,3759,5615,3759,1039,
.dw 3759,5615,3759,1103,3759,5615,3759,1039,
; Pattern 18:
.dw 15,3136,15,1089,15,3136,15,1039,
.dw 15,3136,6292,1103,15,3136,6301,1039,
.dw 15,3136,3140,1089,15,3137,3149,1103,
.dw 4721,3136,4212,1103,15,3137,4221,1071,
.dw 15,2640,4223,1090,15,2640,4223,1103,
.dw 15,2640,6292,1103,15,2641,6301,1103,
.dw 4721,2096,3140,1103,15,2096,3149,1103,
.dw 15,2096,4212,1103,15,2097,4221,1039,
.dw 15,2224,4223,1103,15,2224,4223,1039,
.dw 15,2224,5604,1103,15,2225,5613,1039,
.dw 4721,2224,2804,1089,15,2224,2813,1039,
.dw 4721,2224,3748,1103,15,2225,3757,1039,
.dw 3140,2800,3759,1103,3140,2800,3759,1039,
.dw 3140,2800,5604,1103,3140,2800,5613,1039,
.dw 4721,2800,2804,1089,15,2800,2813,1039,
.dw 15,2800,3748,1103,15,2801,3757,1039,
.dw 3140,3968,3759,1103,3140,3968,3759,1039,
.dw 3140,3968,6292,1103,3140,3969,6301,1039,
.dw 4721,3968,3140,1089,15,3968,3149,1039,
.dw 3140,3968,3972,1103,3140,3969,3981,1039,
.dw 3140,3968,3981,1089,3140,3968,3981,1039,
.dw 3140,3968,6292,1103,3140,3968,6301,1039,
.dw 4721,3968,3140,1103,15,3968,3149,1039,
.dw 15,3968,3972,1103,15,3969,3981,1039,
.dw 3328,4208,3983,1103,3328,4208,3983,1039,
.dw 3328,4208,8420,1103,3328,4209,8429,1039,
.dw 3328,4208,3332,1089,3328,4208,3341,1039,
.dw 4721,4208,4212,1089,15,4209,4221,1039,
.dw 15,4208,4221,1089,15,4208,4221,1103,
.dw 15,4208,8420,1103,15,4208,8429,1039,
.dw 4721,4208,3332,1089,15,4208,3341,1039,
.dw 15,4208,4212,1103,15,4208,4221,1039,
; Pattern 19:
.dw 15,3136,15,1089,15,3136,15,1039,
.dw 15,3136,6292,1103,15,3136,6301,1039,
.dw 15,3136,3140,1089,15,3137,3149,1103,
.dw 4721,3136,4212,1103,15,3137,4221,1071,
.dw 15,2640,4223,1090,15,2640,4223,1103,
.dw 15,2640,6292,1103,15,2641,6301,1103,
.dw 4721,2096,3140,1103,15,2096,3149,1103,
.dw 15,2096,4212,1103,15,2097,4221,1039,
.dw 15,1872,4223,1103,15,1872,4223,1039,
.dw 15,1872,5604,1103,15,1873,5613,1039,
.dw 4721,1872,2804,1089,15,1872,2813,1039,
.dw 4721,1872,3748,1103,15,1873,3757,1039,
.dw 3140,2224,3759,1103,3140,2224,3759,1039,
.dw 3140,2224,5604,1103,3140,2224,5613,1039,
.dw 4721,2224,2804,1089,15,2224,2813,1039,
.dw 15,2224,3748,1103,15,2225,3757,1039,
.dw 3140,4720,3759,1103,3140,4720,3759,1039,
.dw 3140,4720,6292,1103,3140,4721,6301,1039,
.dw 4721,4720,3140,1089,15,4720,3149,1039,
.dw 3140,4720,3972,1103,3140,4721,3981,1039,
.dw 3140,4720,3981,1089,3140,4720,3981,1039,
.dw 3140,4720,6292,1103,3140,4721,6301,1039,
.dw 4721,4720,3140,1103,15,4720,3149,1039,
.dw 15,4720,3972,1103,15,4721,3981,1039,
.dw 3332,4208,3983,1103,3332,4208,3983,1039,
.dw 3332,4208,8420,1103,3332,4208,8429,1039,
.dw 3332,4208,3332,1089,3332,4208,3341,1039,
.dw 4721,4208,4212,1089,15,4208,4221,1039,
.dw 15,4208,4221,1089,15,4208,4221,1103,
.dw 15,4208,8420,1103,15,4208,8429,1039,
.dw 4721,4208,3332,1089,15,4208,3341,1039,
.dw 15,4208,4212,1103,15,4208,4221,1039,
; Pattern 20:
.dw 15,3136,15,1089,15,3136,15,1039,
.dw 15,3136,6292,1103,15,3136,6301,1039,
.dw 15,3136,3140,1089,15,3137,3149,1103,
.dw 4721,3136,4212,1103,15,3137,4221,1071,
.dw 15,2640,4223,1090,15,2640,4223,1103,
.dw 15,2640,6292,1103,15,2641,6301,1103,
.dw 4721,2096,3140,1103,15,2096,3149,1103,
.dw 15,2096,4212,1103,15,2097,4221,1039,
.dw 15,2224,4223,1103,15,2224,4223,1039,
.dw 15,2224,5604,1103,15,2225,5613,1039,
.dw 4721,2224,2804,1089,15,2224,2813,1039,
.dw 4721,2224,3748,1103,15,2225,3757,1039,
.dw 3140,2800,3759,1103,3140,2800,3759,1039,
.dw 3140,2800,5604,1103,3140,2800,5613,1039,
.dw 4721,2800,2804,1089,15,2800,2813,1039,
.dw 15,2800,3748,1103,15,2801,3757,1039,
.dw 3970,4720,3759,1103,3970,4720,3759,1039,
.dw 3970,4720,6292,1103,3970,4721,6301,1039,
.dw 4721,4720,3140,1089,15,4720,3149,1039,
.dw 3970,4720,3972,1103,3970,4721,3981,1039,
.dw 3970,4720,3981,1089,3970,4720,3981,1039,
.dw 3970,4720,6292,1103,3970,4721,6301,1039,
.dw 4721,5296,3140,1103,15,5296,3149,1039,
.dw 15,5296,3972,1103,15,5297,3981,1039,
.dw 4210,6288,3983,1103,4210,6288,3983,1039,
.dw 4210,6288,6292,1103,4210,6288,6301,1039,
.dw 4210,6288,3140,1089,4210,6289,3149,1039,
.dw 4721,6288,4212,1089,15,6289,4221,1039,
.dw 15,6288,4221,1089,15,6288,4221,1103,
.dw 15,6288,6292,1103,15,6288,6301,1039,
.dw 4721,6288,3140,1089,15,6288,3149,1039,
.dw 15,6288,4212,1103,15,6288,4221,1039,
; Pattern 21:
.dw 15,3136,15,1089,15,3136,15,1039,
.dw 15,3136,6292,1103,15,3137,6301,1039,
.dw 15,3136,3140,1103,15,3136,3149,1103,
.dw 3970,3136,4212,1103,3970,3137,4733,1071,
.dw 4721,2800,15,1089,15,2800,15,1103,
.dw 15,2800,6292,1103,15,2801,6301,1103,
.dw 15,2640,3140,1089,15,2640,3149,1103,
.dw 15,2640,4212,1103,15,2641,4221,1039,
.dw 4210,2800,4223,1103,4210,2800,4223,1039,
.dw 4210,2800,5604,1103,4210,2801,5613,1039,
.dw 4721,3328,2804,1103,15,3328,2813,1039,
.dw 4721,3328,3748,1103,15,3329,3757,1039,
.dw 4208,4208,3759,1089,4208,4208,3759,1039,
.dw 4208,4208,5604,1103,4208,4209,5613,1039,
.dw 4721,4208,2804,1089,15,4208,2813,1039,
.dw 15,4208,3748,1103,15,4209,3757,1039,
.dw 15,4720,3759,1090,15,4720,3759,1039,
.dw 15,4720,7956,1103,15,4720,7965,1039,
.dw 4721,4720,3972,1090,15,4721,3981,1039,
.dw 4721,4720,7956,1090,15,4721,7965,1039,
.dw 15,4208,7965,1089,15,4208,7965,1039,
.dw 15,4208,7956,1103,15,4209,7965,1039,
.dw 4721,3968,3972,1090,15,3968,3981,1039,
.dw 15,3968,3972,1103,15,3969,3981,1039,
.dw 15,4208,3983,1090,15,4208,3983,1039,
.dw 15,4208,8420,1103,15,4208,8429,1039,
.dw 4721,4208,3332,1103,15,4208,3341,1039,
.dw 4721,4208,4212,1090,15,4209,4221,1039,
.dw 15,4208,4221,1089,15,4208,4221,1103,
.dw 15,4208,8420,1103,15,4208,8429,1039,
.dw 4721,4208,3332,1090,15,4209,3341,1039,
.dw 15,4208,4212,1103,15,4208,4221,1039,
; Pattern 22:
.dw 4724,4720,15,1103,4724,4720,15,1039,
.dw 4724,4720,9460,1103,4724,4720,9469,1039,
.dw 4724,4720,4724,1089,4724,4721,4733,1103,
.dw 4720,4720,4724,1089,4720,4721,4733,1071,
.dw 4721,4208,4733,1089,15,4208,4733,1103,
.dw 15,4208,9460,1103,15,4209,9469,1103,
.dw 15,3968,4724,1089,15,3968,4733,1103,
.dw 15,3968,4724,1103,15,3969,4733,1039,
.dw 4212,4208,4735,1103,4212,4208,4735,1039,
.dw 4212,4208,8420,1103,4212,4208,8429,1039,
.dw 4212,4208,4212,1089,4212,4208,4221,1039,
.dw 4208,4208,4212,1103,4208,4209,4221,1039,
.dw 4212,4208,4221,1089,4212,4209,4221,1039,
.dw 4212,4720,8420,1103,4212,4721,8429,1039,
.dw 4721,5296,3972,1103,15,5297,3981,1039,
.dw 15,5600,4212,1103,15,5601,4221,1039,
.dw 5300,6288,4223,1089,5300,6288,4223,1039,
.dw 5300,6288,6292,1103,5300,6288,6301,1039,
.dw 4721,6288,3140,1089,15,6288,3149,1039,
.dw 4721,6288,4212,1103,15,6288,4221,1039,
.dw 15,6288,4221,1089,15,6288,4221,1039,
.dw 15,6288,6292,1103,15,6289,6301,1039,
.dw 4721,6288,3140,1103,15,6289,3149,1039,
.dw 15,4208,4212,1103,15,4209,4221,1039,
.dw 15,3136,4223,1089,15,3136,4223,1039,
.dw 15,3136,6292,1089,15,3137,6301,1039,
.dw 4721,3136,3140,1103,15,3136,3149,1039,
.dw 4721,3136,4212,1089,15,3137,4221,1039,
.dw 15,3328,4221,1089,15,3328,4221,1103,
.dw 15,3328,6292,1103,15,3329,6301,1039,
.dw 4721,3328,3140,1103,15,3328,3149,1039,
.dw 15,3328,4212,1103,15,3328,4221,1039,
; Pattern 23:
.dw 15,3136,15,1089,15,3136,15,1039,
.dw 15,3136,6292,1103,15,3136,6301,1039,
.dw 4721,3136,3140,1089,15,3136,3149,1103,
.dw 3136,3136,4212,1103,3136,3136,4733,1071,
.dw 3136,3136,15,1089,3140,3136,15,1103,
.dw 3140,3136,6292,1103,3140,3136,6301,1103,
.dw 3136,3136,3140,1103,3136,3136,3149,1103,
.dw 3136,3136,4212,1103,3140,3136,4221,1039,
.dw 3140,3136,4223,1089,3140,3136,4223,1039,
.dw 3140,3136,6292,1103,3140,3137,6301,1039,
.dw 4721,3136,3140,1103,15,3136,3149,1039,
.dw 4721,3136,4212,1089,15,3136,4221,1039,
.dw 15,3136,4223,1089,15,3137,4223,1039,
.dw 15,3136,6292,1103,15,3136,6301,1039,
.dw 4721,3136,3140,1089,15,3136,3149,1039,
.dw 15,3136,4212,1103,15,3137,4221,1039,
.dw 15,3136,4223,1089,15,3136,4223,1039,
.dw 15,3136,6292,1103,15,3136,6301,1039,
.dw 4721,3136,3140,1089,15,3137,3149,1039,
.dw 4721,3136,4212,1103,15,3136,4221,1039,
.dw 15,3136,4221,1089,15,3136,4221,1039,
.dw 15,3136,6292,1103,15,3136,6301,1039,
.dw 4721,3138,3140,1103,15,3141,3149,1039,
.dw 15,3149,4212,1103,15,3151,4221,1039,
.dw 15,3151,4223,1089,15,3151,4223,1039,
.dw 15,3151,6292,1103,15,3151,6301,1039,
.dw 4721,3136,3140,1103,15,3136,3149,1039,
.dw 4721,3136,4212,1089,15,3140,4221,1039,
.dw 15,3140,4221,1089,15,3140,4221,1103,
.dw 15,3136,6292,1103,15,3136,6301,1039,
.dw 4721,3136,3140,1089,15,3140,3149,1039,
.dw 15,3140,4212,1103,15,3140,4221,1039,
; Pattern 24:
.dw 6289,15,15,1088,6289,15,15,1039,
.dw 6289,15,6290,1103,6290,15,6290,1039,
.dw 3137,15,3140,1103,3137,15,3140,1103,
.dw 3137,15,4215,1088,3138,15,4215,1071,
.dw 4209,15,4215,1088,4209,15,4215,1103,
.dw 4209,15,6299,1103,4210,15,6299,1103,
.dw 5297,15,3149,1103,5297,15,3151,1103,
.dw 5297,15,4221,1103,5298,15,4221,1039,
.dw 6289,15,4221,1103,6289,15,4223,1039,
.dw 6289,15,4223,1103,6289,15,4223,1039,
.dw 6289,15,4223,1103,6289,15,4223,1039,
.dw 6289,15,4223,1103,6289,15,4223,1039,
.dw 6289,15,4223,1103,6291,15,4223,1039,
.dw 6293,15,4223,1103,6297,15,4223,1039,
.dw 6303,15,4223,1103,6303,15,4223,1039,
.dw 6303,15,4223,1103,6303,15,4223,1039,
.dw 6303,15,4223,1103,6303,15,4223,1039,
.dw 6303,15,4223,335,6303,15,4223,271,
.dw 6303,15,4223,335,6303,15,4223,271,
.dw 6303,15,4223,335,6303,15,4223,271,
.dw 6303,15,4223,335,6303,15,4223,271,
.dw 6303,15,4223,335,6303,15,4223,271,
.dw 6303,15,4223,335,6303,15,4223,271,
.dw 6303,15,4223,335,6303,15,4223,271,
.dw 6303,15,4223,335,6303,15,4223,271,
.dw 6303,15,4223,335,6303,15,4223,271,
.dw 6303,15,4223,335,6303,15,4223,271,
.dw 6303,15,4223,335,6303,15,4223,271,
.dw 6303,15,4223,335,6303,15,4223,335,
.dw 6303,15,4223,335,6303,15,4223,271,
.dw 6303,15,4223,335,6303,15,4223,271,
.dw 6303,15,4223,335,6303,15,4223,271,
; Pattern 25:
.dw 7073,7074,7074,1091,7073,15,7074,1039,
.dw 7073,15,7074,1095,7074,15,7074,1039,
.dw 3537,4723,7074,1095,3538,15,7074,1103,
.dw 3537,3539,3538,1091,3537,15,3538,1071,
.dw 3537,3540,3538,1095,3537,15,3538,1103,
.dw 3537,3539,7074,1091,3537,15,7074,1103,
.dw 3537,3540,3538,1091,3537,15,3538,1103,
.dw 3537,15,3538,1099,3538,15,4731,1039,
.dw 7073,15,3142,1091,7074,15,4212,1039,
.dw 3537,7074,4722,1091,3537,15,15,1039,
.dw 3537,15,15,1091,3538,15,15,1039,
.dw 7073,15,15,1103,7074,15,15,1039,
.dw 7489,7074,7490,1091,7489,15,7490,1039,
.dw 7489,15,7490,1094,7490,15,7490,1039,
.dw 3745,15,7490,1094,3746,15,7490,1039,
.dw 3745,15,3746,1091,3745,15,3746,1039,
.dw 3745,15,3746,1094,3745,15,3746,1039,
.dw 3745,15,7490,1091,3745,15,7490,1039,
.dw 3745,15,3746,1091,3745,15,3746,1039,
.dw 3745,15,3746,1099,3746,15,3746,1039,
.dw 7489,15,3138,1091,7490,15,3147,1039,
.dw 3745,15,3142,1091,3745,15,3140,1039,
.dw 3745,15,3747,1091,3746,15,4995,1039,
.dw 7489,15,7074,1091,7489,15,15,-31729,
.dw 7489,15,15,1103,7489,15,15,1039,
.dw 7489,15,15,1103,7489,15,15,1039,
.dw 7489,15,15,1103,7489,15,15,1039,
.dw 7489,15,15,1103,7489,15,15,1039,
.dw 7489,15,15,1103,7489,15,15,1103,
.dw 7489,15,15,1103,7489,15,15,1039,
.dw 7489,15,15,1103,7489,15,15,1039,
.dw 7489,15,15,1103,7489,15,15,1039,
; Pattern 26:
.dw 4721,4724,9458,1858,4721,4724,9458,1807,
.dw 4721,4724,9458,1871,6289,4724,4722,1858,
.dw 4721,4724,4723,1871,4209,4724,4722,1859,
.dw 3969,4724,7954,1858,3969,4724,7954,1839,
.dw 3969,4724,7954,1871,4209,4724,6290,1858,
.dw 4209,4724,6290,1871,4209,4724,6290,1859,
.dw 4721,4724,6290,1858,4721,4724,6290,1871,
.dw 4721,5940,7074,1871,6289,5940,3538,1858,
.dw 4721,5940,3539,1871,3969,5940,3538,1859,
.dw 3137,5940,5938,1858,3137,5940,5938,1807,
.dw 3137,5940,5938,1871,3537,5940,4722,1858,
.dw 3537,5940,4722,1871,3537,5940,4722,1859,
.dw 3969,5940,4722,1858,3969,5940,4722,1807,
.dw 3969,4724,9458,1871,3969,4724,4722,1858,
.dw 3970,4724,4723,1871,3970,4724,4722,1859,
.dw 3137,4724,7954,1858,3137,4724,7954,1807,
.dw 3137,4724,7954,1871,3137,4724,6290,1858,
.dw 3138,4724,6290,1871,4721,4724,6290,1859,
.dw 4465,4724,6290,1858,4465,4724,6290,1807,
.dw 3969,4996,8930,1871,3537,4996,4466,1858,
.dw 3537,4996,4467,1871,2497,4996,4466,1859,
.dw 2497,4996,7074,1858,2497,4996,7074,1807,
.dw 2497,4996,7074,1871,2497,4996,5938,1858,
.dw 2498,4996,5938,1871,2499,4996,5938,-30909,
.dw 2500,4996,5938,-30910,2501,4996,5938,-30961,
.dw 2501,4996,5938,1871,2501,4996,5938,1807,
.dw 2501,4996,5938,1871,2501,4996,5938,1807,
.dw 2501,4996,5938,1871,2501,4996,5938,1807,
.dw 2501,4996,5938,1871,2501,4996,5938,1871,
.dw 2501,4996,5938,1871,2501,4996,5938,1807,
.dw 2501,4996,5938,1871,2501,4996,5938,1807,
.dw 2501,4996,5938,1871,2501,4996,5938,1807,
; Pattern 27:
.dw 4721,15,15,1858,4721,15,15,1807,
.dw 4721,4724,9458,1871,6289,4724,4722,1858,
.dw 4721,4724,4723,1871,4209,4724,4722,1859,
.dw 3969,4724,7954,1858,3969,4724,7954,1839,
.dw 3969,4724,7954,1871,4209,4724,6290,1858,
.dw 4209,4724,6290,1871,4209,4724,6290,1859,
.dw 4721,4724,6290,1858,4721,4724,6290,1871,
.dw 4721,5940,5938,1871,6289,5940,5941,1858,
.dw 4721,5940,5941,1871,3969,5940,3330,1859,
.dw 3137,5940,3333,1858,3137,5940,3333,1807,
.dw 3137,5940,3538,1871,3537,5940,3970,1858,
.dw 3537,5940,3970,1871,3537,5940,3970,1859,
.dw 3969,5940,3970,1858,3969,5940,3970,1807,
.dw 3137,6292,6290,1871,3137,6292,6297,1858,
.dw 3137,6292,6297,1871,3137,6292,6290,1859,
.dw 2353,6292,6297,1858,2353,6292,6297,1807,
.dw 1985,6292,6290,1871,1985,6292,6290,1858,
.dw 1985,6292,6290,1871,1985,6292,6290,-30909,
.dw 2353,6292,6291,-30910,2353,6292,6291,1807,
.dw 2353,4996,4722,-30897,2353,4996,4722,-30910,
.dw 2353,4996,4722,1871,2353,4996,4722,1859,
.dw 2353,4996,4722,1858,2353,4996,4722,1807,
.dw 2353,4996,4722,1871,2353,4996,4722,1858,
.dw 2353,4996,4722,1871,2353,4996,4722,1859,
.dw 2353,4996,4722,-30910,2353,4996,4722,-30961,
.dw 2353,4996,4722,1871,2353,4996,4722,1807,
.dw 2353,4996,4722,1871,2353,4996,4722,1807,
.dw 2353,4996,4722,1871,2353,4996,4722,1807,
.dw 2353,4996,4722,1871,2353,4996,4722,1871,
.dw 2353,4996,4722,1871,2353,4996,4722,1807,
.dw 2353,4996,4722,1871,2353,4996,4722,1807,
.dw 2353,4996,4722,1871,2353,4996,4722,1807,
; Pattern 28:
.dw 2353,3968,15,1858,2353,3969,15,1807,
.dw 2353,4721,4722,1871,2353,3328,7954,1858,
.dw 2354,3329,7957,1871,2354,3137,7954,1859,
.dw 2355,3968,6290,1858,2355,3969,6290,1839,
.dw 2356,4721,6290,1871,4722,3328,4722,1858,
.dw 4723,3329,4722,1871,4722,3137,4722,1859,
.dw 4722,3968,4722,1858,4722,3969,4722,1871,
.dw 4723,4721,5938,1871,4723,3536,5938,1858,
.dw 4723,3537,5938,1871,4723,3329,5938,1859,
.dw 4723,3968,7954,1858,4723,3969,7954,1807,
.dw 4723,4721,7954,1871,4723,3536,5938,1858,
.dw 4724,3537,5938,1871,4724,3329,5938,1859,
.dw 4724,3968,5938,1858,4724,3969,5938,1807,
.dw 4724,4721,9458,1871,4724,3328,9458,1858,
.dw 4724,3329,9458,1871,4724,3137,9458,1859,
.dw 4725,3968,7954,1858,4725,3969,7954,1807,
.dw 4725,4721,7954,1871,4722,3328,6290,1858,
.dw 4723,3329,6290,1871,4722,3137,6290,1859,
.dw 4722,3968,6290,1858,4722,3969,6290,1807,
.dw 4723,4721,6290,1871,4723,3536,5938,1858,
.dw 4723,3537,5938,1871,4723,3329,5938,1859,
.dw 4723,3968,7954,1858,4723,3969,7954,1807,
.dw 4723,4721,7954,1871,4723,3536,5938,1858,
.dw 4724,3537,5938,1871,4724,3329,5938,-30909,
.dw 4724,3968,5938,1858,4724,3968,5938,1807,
.dw 4724,3968,5938,-30897,4724,3968,5938,1807,
.dw 4724,3968,5938,1871,4724,3968,5938,1807,
.dw 4724,3968,5938,1871,4724,3968,5938,1807,
.dw 4724,3968,5938,1871,4724,3968,5938,1871,
.dw 4724,3968,5938,1871,4724,3968,5938,1807,
.dw 4724,3968,5938,1871,4724,3968,5938,1807,
.dw 4724,3968,5938,1871,4724,3968,5938,1807,
; Pattern 29:
.dw 15,3968,15,1858,15,3969,15,1807,
.dw 15,4721,9458,1871,15,3328,9461,1858,
.dw 15,3329,9461,1871,15,3137,9458,1859,
.dw 15,3968,7954,1858,15,3969,7954,1839,
.dw 15,4721,7954,1871,4722,3328,6290,1858,
.dw 4723,3329,6290,1871,3330,3137,6290,1859,
.dw 3330,3968,6290,1858,3330,3969,6290,1871,
.dw 3331,4721,5938,1871,3331,3536,5941,1858,
.dw 3331,3537,5941,1871,3331,3329,5938,1859,
.dw 3331,3968,7954,1858,3331,3969,7954,1807,
.dw 3331,4721,7954,1871,3331,3536,9458,1858,
.dw 3331,3537,9458,1871,3331,3329,9458,1859,
.dw 3138,3968,9458,1858,3138,3969,9458,1807,
.dw 3139,4721,9458,1871,3139,3328,6290,1858,
.dw 3139,3329,6293,1871,3139,3137,6290,1859,
.dw 3138,3968,7954,1858,3138,3969,7954,1807,
.dw 3138,4721,7954,1871,3969,3328,9458,1858,
.dw 3969,3329,9458,1871,4209,3137,9458,1859,
.dw 4209,3968,9458,1858,4209,3969,9458,1807,
.dw 4209,4993,6290,1871,4209,3328,6293,1858,
.dw 4209,3329,6293,1871,4209,3137,6290,1859,
.dw 4209,4208,8418,1858,4209,4209,8418,1807,
.dw 4209,4993,8418,1871,4209,3328,6289,1858,
.dw 4209,3329,6289,1871,4209,3137,6289,1859,
.dw 4209,4208,6289,1858,4209,4209,6289,1807,
.dw 4209,4992,6289,-30897,4209,4992,6289,1807,
.dw 4209,4992,6289,1871,4209,4992,6289,1807,
.dw 4209,4992,6289,1871,4209,4992,6289,1807,
.dw 4209,4992,6289,1871,4209,4992,6289,1871,
.dw 4209,4992,6289,1871,4209,4992,6289,1807,
.dw 4209,4992,6289,1871,4209,4992,6289,1807,
.dw 4209,4992,6289,1871,4209,4992,6289,1807,
; Pattern 30:
.dw 4724,4720,9458,1858,4729,4720,9458,1807,
.dw 4724,4722,9459,1862,4729,4722,9459,1871,
.dw 4724,4724,9461,1867,4729,4724,9461,1871,
.dw 4735,4727,9465,1871,4735,4727,9465,1839,
.dw 4735,4727,9465,1871,4735,4729,9467,1871,
.dw 4735,4731,9469,1871,4735,4733,9471,1871,
.dw 4735,4735,9471,1871,4735,4735,9471,1871,
.dw 4735,4735,9471,1871,4735,4735,9471,1871,
.dw 4735,4735,9471,1871,4735,4735,9471,1871,
.dw 4735,4735,9471,-30897,4735,4735,9471,1807,
.dw 4735,4735,9471,1871,4735,4735,9471,1871,
.dw 4735,4735,9471,1871,4735,4735,9471,1871,
.dw 4735,4735,9471,1871,4735,4735,9471,1807,
.dw 4735,4735,9471,1871,4735,4735,9471,1871,
.dw 4735,4735,9471,1871,4735,4735,9471,1871,
.dw 4735,4735,9471,1871,4735,4735,9471,1807,
.dw 4735,4735,9471,1871,4735,4735,9471,1871,
.dw 4735,4735,9471,1871,4735,4735,9471,1871,
.dw 4735,4735,9471,1871,4735,4735,9471,1807,
.dw 4735,4735,9471,1871,4735,4735,9471,1871,
.dw 4735,4735,9471,1871,4735,4735,9471,1871,
.dw 4735,4735,9471,1871,4735,4735,9471,1807,
.dw 4735,4735,9471,1871,4735,4735,9471,1871,
.dw 4735,4735,9471,1871,4735,4735,9471,1871,
.dw 4735,4735,9471,1871,4735,4735,9471,1807,
.dw 4735,4735,9471,1871,4735,4735,9471,1807,
.dw 4735,4735,9471,1871,4735,4735,9471,1807,
.dw 4735,4735,9471,1871,4735,4735,9471,1807,
.dw 4735,4735,9471,1871,4735,4735,9471,1871,
.dw 4735,4735,9471,1871,4735,4735,9471,1807,
.dw 4735,4735,9471,1871,4735,4735,9471,1807,
.dw 4735,4735,9471,1871,4735,4735,9471,1807,

.org $10000
.end
